#
# spec file for package aws-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%define pythons python311
%endif
%global _sitelibdir %{%{pythons}_sitelib}

Name:           aws-cli
Version:        1.32.105
Release:        1.1
Summary:        Amazon Web Services Command Line Interface
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/aws/aws-cli
Source0:        https://github.com/aws/%{name}/archive/refs/tags/%{version}.tar.gz
Patch0:         ac_update-docutils.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       groff
Provides:       awscli = %{version}
BuildArch:      noarch
BuildRequires:  %{pythons}-devel
BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-setuptools
BuildRequires:  %{pythons}-wheel
Requires:       %{pythons}
Requires:       %{pythons}-botocore >= 1.34.105
Requires:       %{pythons}-six
Requires:       (%{pythons}-PyYAML >= 3.10 with %{pythons}-PyYAML <= 6.1)
Requires:       (%{pythons}-colorama >= 0.2.5 with %{pythons}-colorama <= 0.5.0)
Requires:       (%{pythons}-docutils >= 0.10 with %{pythons}-docutils < 0.21)
Requires:       (%{pythons}-rsa >= 3.1.2 with %{pythons}-rsa < 5.0.0)
Requires:       (%{pythons}-s3transfer >= 0.10.0 with %{pythons}-s3transfer < 0.11.0)

%description
The AWS Command Line Interface (CLI) is a unified tool to manage AWS
services. With this tool, multiple AWS services can be controlled
from the command line and automated through scripts.

%prep
%autosetup -p1
sed -i 's/from botocore\.vendored //' awscli/customizations/awslambda.py
sed -i 's/botocore\.vendored\.//' awscli/customizations/configure/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
find %{buildroot}%{_sitelibdir}/awscli/examples -type f -exec chmod 644 {} \;
# No DOS crap
rm %{buildroot}/%{_bindir}/aws.cmd
# Shell completion
install -DTm644 %{buildroot}%{_bindir}/aws_bash_completer %{buildroot}%{_datadir}/bash-completion/completions/aws
install -DTm644 %{buildroot}%{_bindir}/aws_zsh_completer.sh %{buildroot}%{_sysconfdir}/zsh_completion.d/_aws

%files
%defattr(-, root, root)
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%dir %{_sitelibdir}/awscli
%dir %{_sitelibdir}/awscli-%{version}*-info
%{_sitelibdir}/awscli/*
%{_sitelibdir}/awscli-%{version}*-info/*
%{_bindir}/aws
%{_bindir}/aws_completer
%exclude %{_bindir}/aws_bash_completer
%exclude %{_bindir}/aws_zsh_completer.sh
%{_datadir}/bash-completion/completions/aws
%dir %{_sysconfdir}/zsh_completion.d
%config %attr(644,root,root) %{_sysconfdir}/zsh_completion.d/_aws

%changelog
* Thu May 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.32.105
  * api-change:``connect``: Amazon Connect provides enhanced search capabilities for flows & flow
    modules on the Connect admin website and programmatically using APIs. You can search for flows and
    flow modules by name, description, type, status, and tags, to filter and identify a specific flow
    in your Connect instances.
  * api-change:``s3``: Updated a few x-id in the http uri traits
- from version 1.32.104
  * api-change:``events``: Amazon EventBridge introduces KMS customer-managed key (CMK) encryption
    support for custom and partner events published on EventBridge Event Bus (including default bus)
    and UpdateEventBus API.
  * api-change:``vpc-lattice``: This release adds TLS Passthrough support. It also increases max
    number of target group per rule to 10.
- from version 1.32.103
  * api-change:``discovery``: add v2 smoke tests and smithy smokeTests trait for SDK testing
  * api-change:``greengrassv2``: Mark ComponentVersion in ComponentDeploymentSpecification as
    required.
  * api-change:``sagemaker``: Introduced support for G6 instance types on Sagemaker Notebook
    Instances and on SageMaker Studio for JupyterLab and CodeEditor applications.
  * api-change:``sso-oidc``: Updated request parameters for PKCE support.
- from version 1.32.102
  * api-change:``bedrock-agent-runtime``: This release adds support to provide guardrail
    configuration and modify inference parameters that are then used in RetrieveAndGenerate API in
    Agents for Amazon Bedrock.
  * api-change:``pinpoint``: This release adds support for specifying email message headers for Email
    Templates, Campaigns, Journeys and Send Messages.
  * api-change:``route53resolver``: Update the DNS Firewall settings to correct a spelling issue.
  * api-change:``ssm-sap``: Added support for application-aware start/stop of SAP applications
    running on EC2 instances, with SSM for SAP
  * api-change:``verifiedpermissions``: Adds policy effect and actions fields to Policy API's.
- from version 1.32.101
  * api-change:``cognito-idp``: Add EXTERNAL_PROVIDER enum value to UserStatusType.
  * api-change:``ec2``: Adding Precision Hardware Clock (PHC) to public API DescribeInstanceTypes
  * api-change:``ecr``: This release adds pull through cache rules support for GitLab container
    registry in Amazon ECR.
  * api-change:``fms``: The policy scope resource tag is always a string value, either a non-empty
    string or an empty string.
  * api-change:``polly``: Add new engine - generative - that builds the most expressive
    conversational voices.
  * api-change:``sqs``: This release adds MessageSystemAttributeNames to ReceiveMessageRequest to
    replace AttributeNames.
- from version 1.32.100
  * api-change:``b2bi``: Documentation update to clarify the MappingTemplate definition.
  * api-change:``budgets``: This release adds tag support for budgets and budget actions.
  * api-change:``resiliencehub``: AWS Resilience Hub has expanded its drift detection capabilities by
    introducing a new type of drift detection - application resource drift. This new enhancement
    detects changes, such as the addition or deletion of resources within the application's input
    sources.
  * api-change:``route53profiles``: Doc only update for Route 53 profiles that fixes some link  issues
- from version 1.32.99
  * api-change:``medialive``: AWS Elemental MediaLive now supports configuring how SCTE 35
    passthrough triggers segment breaks in HLS and MediaPackage output groups. Previously, messages
    triggered breaks in all these output groups. The new option is to trigger segment breaks only in
    groups that have SCTE 35 passthrough enabled.
- from version 1.32.98
  * api-change:``bedrock-agent``: This release adds support for using Provisioned Throughput with
    Bedrock Agents.
  * api-change:``connect``: This release adds 5 new APIs for managing attachments:
    StartAttachedFileUpload, CompleteAttachedFileUpload, GetAttachedFile, BatchGetAttachedFileMetadata,
    DeleteAttachedFile. These APIs can be used to programmatically upload and download attachments to
    Connect resources, like cases.
  * api-change:``connectcases``: This feature supports the release of Files related items
  * api-change:``datasync``: Updated guidance on using private or self-signed certificate authorities
    (CAs) with AWS DataSync object storage locations.
  * api-change:``inspector2``: This release adds CSV format to GetCisScanReport for Inspector v2
  * api-change:``sagemaker``: Amazon SageMaker Inference now supports m6i, c6i, r6i, m7i, c7i, r7i
    and g5 instance types for Batch Transform Jobs
  * api-change:``sesv2``: Adds support for specifying replacement headers per BulkEmailEntry in
    SendBulkEmail in SESv2.
- from version 1.32.97
  * api-change:``dynamodb``: This release adds support to specify an optional, maximum
    OnDemandThroughput for DynamoDB tables and global secondary indexes in the CreateTable or
    UpdateTable APIs. You can also override the OnDemandThroughput settings by calling the ImportTable,
    RestoreFromPointInTime, or RestoreFromBackup APIs.
  * api-change:``ec2``: This release includes a new API for retrieving the public endorsement key of
    the EC2 instance's Nitro Trusted Platform Module (NitroTPM).
  * api-change:``personalize``: This releases ability to delete users and their data, including their
    metadata and interactions data, from a dataset group.
  * api-change:``redshift-serverless``: Update Redshift Serverless List Scheduled Actions Output
    Response to include Namespace Name.
- from version 1.32.96
  * api-change:``bedrock-agent``: This release adds support for using MongoDB Atlas as a vector store
    when creating a knowledge base.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``personalize-runtime``: This release adds support for a Reason attribute for
    predicted items generated by User-Personalization-v2.
  * api-change:``securityhub``: Updated CreateMembers API request with limits.
  * api-change:``sesv2``: Fixes ListContacts and ListImportJobs APIs to use POST instead of GET.
- from version 1.32.95
  * api-change:``chime-sdk-voice``: Due to changes made by the Amazon Alexa service,
    GetSipMediaApplicationAlexaSkillConfiguration and PutSipMediaApplicationAlexaSkillConfiguration
    APIs are no longer available for use. For more information, refer to the Alexa Smart Properties
    page.
  * api-change:``codeartifact``: Add support for the Ruby package format.
  * api-change:``fms``: AWS Firewall Manager now supports the network firewall service stream
    exception policy feature for accounts within your organization.
  * api-change:``omics``: Add support for workflow sharing and dynamic run storage
  * api-change:``opensearch``: This release enables customers to create Route53 A and AAAA alias
    record types to point custom endpoint domain to OpenSearch domain's dualstack search endpoint.
  * api-change:``pinpoint-sms-voice-v2``: Amazon Pinpoint has added two new features Multimedia
    services (MMS) and protect configurations. Use the three new MMS APIs to send media messages to a
    mobile phone which includes image, audio, text, or video files. Use the ten new protect
    configurations APIs to block messages to specific countries.
  * api-change:``qbusiness``: This is a general availability (GA) release of Amazon Q Business. Q
    Business enables employees in an enterprise to get comprehensive answers to complex questions and
    take actions through a unified, intuitive web-based chat experience - using an enterprise's
    existing content, data, and systems.
  * api-change:``quicksight``: New Q embedding supporting Generative Q&A
  * api-change:``route53resolver``: Release of FirewallDomainRedirectionAction parameter on the Route
    53 DNS Firewall Rule.  This allows customers to configure a DNS Firewall rule to inspect all the
    domains in the DNS redirection chain (default) , such as CNAME, ALIAS, DNAME, etc., or just the
    first domain and trust the rest.
  * api-change:``sagemaker``: Amazon SageMaker Training now supports the use of attribute-based
    access control (ABAC) roles for training job execution roles. Amazon SageMaker Inference now
    supports G6 instance types.
  * api-change:``signer``: Documentation updates for AWS Signer. Adds cross-account signing
    constraint and definitions for cross-account actions.
- from version 1.32.94
  * api-change:``amplify``: Updating max results limit for listing any resources (Job, Artifacts,
    Branch, BackendResources, DomainAssociation) to 50 with the exception of list apps that where max
    results can be up to 100.
  * api-change:``connectcases``: This feature releases DeleteField, DeletedLayout, and DeleteTemplate
    API's
  * api-change:``inspector2``: Update Inspector2 to include new Agentless API parameters.
  * api-change:``timestream-query``: This change allows users to update and describe account settings
    associated with their accounts.
  * api-change:``transcribe``: This update provides error messaging for generative call summarization
    in Transcribe Call Analytics
  * api-change:``trustedadvisor``: This release adds the BatchUpdateRecommendationResourceExclusion
    API to support batch updates of Recommendation Resource exclusion statuses and introduces a new
    exclusion status filter to the ListRecommendationResources and
    ListOrganizationRecommendationResources APIs.
- from version 1.32.93
  * api-change:``codepipeline``: Add ability to manually and automatically roll back a pipeline stage
    to a previously successful execution.
  * api-change:``cognito-idp``: Add LimitExceededException to SignUp errors
  * api-change:``connectcampaigns``: This release adds support for specifying if Answering Machine
    should wait for prompt sound.
  * api-change:``marketplace-entitlement``: Releasing minor endpoint updates.
  * api-change:``oam``: This release introduces support for Source Accounts to define which Metrics
    and Logs to share with the Monitoring Account
  * api-change:``rds``: SupportsLimitlessDatabase field added to describe-db-engine-versions to
    indicate whether the DB engine version supports Aurora Limitless Database.
  * api-change:``support``: Releasing minor endpoint updates.
  * enhancement:dependency: Bump upper bound of colorama to <0.4.7; fixes `#7086
    <https://github.com/aws/aws-cli/issues/7086>`__
- from version 1.32.92
  * api-change:``appsync``: UpdateGraphQLAPI documentation update and datasource introspection secret
    arn update
  * api-change:``fms``: AWS Firewall Manager adds support for network ACL policies to manage Amazon
    Virtual Private Cloud (VPC) network access control lists (ACLs) for accounts in your organization.
  * api-change:``ivs``: Bug Fix: IVS does not support arns with the `svs` prefix
  * api-change:``ivs-realtime``: Bug Fix: IVS Real Time does not support ARNs using the `svs` prefix.
  * api-change:``rds``: Updates Amazon RDS documentation for setting local time zones for RDS for Db2
    DB instances.
  * api-change:``stepfunctions``: Add new ValidateStateMachineDefinition operation, which performs
    syntax checking on the definition of a Amazon States Language (ASL) state machine.
- from version 1.32.91
  * api-change:``datasync``: This change allows users to disable and enable the schedules associated
    with their tasks.
  * api-change:``ec2``: Launching capability for customers to enable or disable automatic assignment
    of public IPv4 addresses to their network interface
  * api-change:``emr-containers``: EMRonEKS Service support for SecurityConfiguration enforcement for
    Spark Jobs.
  * api-change:``entityresolution``: Support Batch Unique IDs Deletion.
  * api-change:``gamelift``: Amazon GameLift releases container fleets support for public preview.
    Deploy Linux-based containerized game server software for hosting on Amazon GameLift.
  * api-change:``ssm``: Add SSM DescribeInstanceProperties API to public AWS SDK.
- from version 1.32.90
  * api-change:``bedrock``: This release introduces Model Evaluation and Guardrails for Amazon
    Bedrock.
  * api-change:``bedrock-agent``: Introducing the ability to create multiple data sources per
    knowledge base, specify S3 buckets as data sources from external accounts, and exposing levers to
    define the deletion behavior of the underlying vector store data.
  * api-change:``bedrock-agent-runtime``: This release introduces zero-setup file upload support for
    the RetrieveAndGenerate API. This allows you to chat with your data without setting up a Knowledge
    Base.
  * api-change:``bedrock-runtime``: This release introduces Guardrails for Amazon Bedrock.
  * api-change:``ce``: Added additional metadata that might be applicable to your reservation
    recommendations.
  * api-change:``ec2``: This release introduces EC2 AMI Deregistration Protection, a new AMI property
    that can be enabled by customers to protect an AMI against an unintended deregistration. This
    release also enables the AMI owners to view the AMI 'LastLaunchedTime' in DescribeImages API.
  * api-change:``pi``: Clarifies how aggregation works for GetResourceMetrics in the Performance
    Insights API.
  * api-change:``rds``: Fix the example ARN for ModifyActivityStreamRequest
  * api-change:``workspaces-web``: Added InstanceType and MaxConcurrentSessions parameters on
    CreatePortal and UpdatePortal Operations as well as the ability to read Customer Managed Key &
    Additional Encryption Context parameters on supported resources (Portal, BrowserSettings,
    UserSettings, IPAccessSettings)
- from version 1.32.89
  * api-change:``bedrock-agent``: Releasing the support for simplified configuration and return of
    control
  * api-change:``bedrock-agent-runtime``: Releasing the support for simplified configuration and
    return of control
  * api-change:``payment-cryptography``: Adding support to TR-31/TR-34 exports for optional headers,
    allowing customers to add additional metadata (such as key version and KSN) when exporting keys
    from the service.
  * api-change:``redshift-serverless``: Updates description of schedule field for scheduled actions.
  * api-change:``route53profiles``: Route 53 Profiles allows you to apply a central DNS configuration
    across many VPCs regardless of account.
  * api-change:``sagemaker``: This release adds support for Real-Time Collaboration and Shared Space
    for JupyterLab App on SageMaker Studio.
  * api-change:``servicediscovery``: This release adds examples to several Cloud Map actions.
  * api-change:``transfer``: Adding new API to support remote directory listing using SFTP connector
- from version 1.32.88
  * api-change:``glue``: Adding RowFilter in the response for GetUnfilteredTableMetadata API
  * api-change:``internetmonitor``: This update introduces the GetInternetEvent and
    ListInternetEvents APIs, which provide access to internet events displayed on the Amazon CloudWatch
    Internet Weather Map.
  * api-change:``personalize``: This releases auto training capability while creating a solution and
    automatically syncing latest solution versions when creating/updating a campaign
- from version 1.32.87
  * api-change:``drs``: Outpost ARN added to Source Server and Recovery Instance
  * api-change:``emr-serverless``: This release adds the capability to publish detailed Spark engine
    metrics to Amazon Managed Service for Prometheus (AMP) for  enhanced monitoring for Spark jobs.
  * api-change:``guardduty``: Added IPv6Address fields for local and remote IP addresses
  * api-change:``quicksight``: This release adds support for the Cross Sheet Filter and Control
    features, and support for warnings in asset imports for any permitted errors encountered during
    execution
  * api-change:``rolesanywhere``: This release introduces the PutAttributeMapping and
    DeleteAttributeMapping APIs. IAM Roles Anywhere now provides the capability to define a set of
    mapping rules, allowing customers to specify which data is extracted from their X.509 end-entity
    certificates.
  * api-change:``sagemaker``: Removed deprecated enum values and updated API documentation.
  * api-change:``workspaces``: Adds new APIs for managing and sharing WorkSpaces BYOL configuration
    across accounts.
- from version 1.32.86
  * api-change:``ec2``: Documentation updates for Elastic Compute Cloud (EC2).
  * api-change:``qbusiness``: This release adds support for IAM Identity Center (IDC) as the identity
    gateway for Q Business. It also allows users to provide an explicit intent for Q Business to
    identify how the Chat request should be handled.
- from version 1.32.85
  * api-change:``bedrock-agent``: For Create Agent API, the agentResourceRoleArn parameter is no
    longer required.
  * api-change:``emr-serverless``: This release adds support for shuffle optimized disks that allow
    larger disk sizes and higher IOPS to efficiently run shuffle heavy workloads.
  * api-change:``entityresolution``: Cross Account Resource Support .
  * api-change:``iotwireless``: Add PublicGateways in the GetWirelessStatistics call response,
    indicating the LoRaWAN public network accessed by the device.
  * api-change:``lakeformation``: This release adds Lake Formation managed RAM support for the 4 APIs
  - "DescribeLakeFormationIdentityCenterConfiguration",
    "CreateLakeFormationIdentityCenterConfiguration",
    "DescribeLakeFormationIdentityCenterConfiguration", and
    "DeleteLakeFormationIdentityCenterConfiguration"
  * api-change:``m2``: Adding new ListBatchJobRestartPoints API and support for restart batch job.
  * api-change:``mediapackagev2``: Dash v2 is a MediaPackage V2 feature to support egressing on DASH
    manifest format.
  * api-change:``outposts``: This release adds new APIs to allow customers to configure their Outpost
    capacity at order-time.
  * api-change:``wellarchitected``: AWS Well-Architected now has a Connector for Jira to allow
    customers to efficiently track workload risks and improvement efforts and create closed-loop
    mechanisms.
- from version 1.32.84
  * api-change:``cloudformation``: Adding support for the new parameter "IncludePropertyValues" in
    the CloudFormation DescribeChangeSet API. When this parameter is included, the DescribeChangeSet
    response will include more detailed information such as before and after values for the resource
    properties that will change.
  * api-change:``config``: Updates documentation for AWS Config
  * api-change:``glue``: Modifying request for GetUnfilteredTableMetadata for view-related fields.
  * api-change:``healthlake``: Added new CREATE_FAILED status for data stores. Added new errorCause
    to DescribeFHIRDatastore API and ListFHIRDatastores API response for additional insights into data
    store creation and deletion workflows.
  * api-change:``iotfleethub``: Documentation updates for AWS IoT Fleet Hub to clarify that Fleet Hub
    supports organization instance of IAM Identity Center.
  * api-change:``kms``: This feature supports the ability to specify a custom rotation period for
    automatic key rotations, the ability to perform on-demand key rotations, and visibility into your
    key material rotations.
  * api-change:``mediatailor``: Added InsertionMode to PlaybackConfigurations. This setting controls
    whether players can use stitched or guided ad insertion. The default for players that do not
    specify an insertion mode is stitched.
  * api-change:``neptune-graph``: Update to API documentation to resolve customer reported issues.
  * api-change:``outposts``: This release adds EXPEDITORS as a valid shipment carrier.
  * api-change:``redshift``: Adds support for Amazon Redshift DescribeClusterSnapshots API to include
    Snapshot ARN response field.
  * api-change:``transfer``: This change releases support for importing self signed certificates to
    the Transfer Family for sending outbound file transfers over TLS/HTTPS.
- from version 1.32.83
  * api-change:``batch``: This release adds the task properties field to attempt details and the name
    field on EKS container detail.
  * api-change:``cloudfront``: CloudFront origin access control extends support to AWS Lambda
    function URLs and AWS Elemental MediaPackage v2 origins.
  * api-change:``cloudwatch``: This release adds support for Metric Characteristics for CloudWatch
    Anomaly Detection. Anomaly Detector now takes Metric Characteristics object with Periodic Spikes
    boolean field that tells Anomaly Detection that spikes that repeat at the same time every week are
    part of the expected pattern.
  * api-change:``codebuild``: Support access tokens for Bitbucket sources
  * api-change:``iam``: For CreateOpenIDConnectProvider API, the ThumbprintList parameter is no
    longer required.
  * api-change:``medialive``: AWS Elemental MediaLive introduces workflow monitor, a new feature that
    enables the visualization and monitoring of your media workflows. Create signal maps of your
    existing workflows and monitor them by creating notification and monitoring template groups.
  * api-change:``omics``: This release adds support for retrieval of S3 direct access metadata on
    sequence stores and read sets, and adds support for SHA256up and SHA512up HealthOmics ETags.
  * api-change:``pipes``: LogConfiguration ARN validation fixes
  * api-change:``rds``: Updates Amazon RDS documentation for Standard Edition 2 support in RDS Custom
    for Oracle.
  * api-change:``s3control``: Documentation updates for Amazon S3-control.
- from version 1.32.82
  * api-change:``cleanrooms``: AWS Clean Rooms Differential Privacy is now fully available.
    Differential privacy protects against user-identification attempts.
  * api-change:``connect``: This release adds new Submit Auto Evaluation Action for Amazon Connect
    Rules.
  * api-change:``networkmonitor``: Examples were added to CloudWatch Network Monitor commands.
  * api-change:``qconnect``: This release adds a new QiC public API updateSession and updates an
    existing QiC public API createSession
  * api-change:``rekognition``: Added support for ContentType to content moderation detections.
  * api-change:``supplychain``: This release includes API SendDataIntegrationEvent for AWS Supply
    Chain
  * api-change:``workspaces-thin-client``: Adding tags field to SoftwareSet. Removing tags fields
    from Summary objects. Changing the list of exceptions in tagging APIs. Fixing an issue where the
    SDK returns empty tags in Get APIs.
- from version 1.32.81
  * api-change:``codebuild``: Add new webhook filter types for GitHub webhooks
  * api-change:``mediaconvert``: This release includes support for bringing your own fonts to use for
    burn-in or DVB-Sub captioning workflows.
  * api-change:``pinpoint``: The OrchestrationSendingRoleArn has been added to the email channel and
    is used to send emails from campaigns or journeys.
  * api-change:``rds``: This release adds support for specifying the CA certificate to use for the
    new db instance when restoring from db snapshot, restoring from s3, restoring to point in time, and
    creating a db instance read replica.
- from version 1.32.80
  * api-change:``controlcatalog``: This is the initial SDK release for AWS Control Catalog, a central
    catalog for AWS managed controls. This release includes 3 new APIs - ListDomains, ListObjectives,
    and ListCommonControls - that vend high-level data to categorize controls across the AWS platform.
  * api-change:``mgn``: Added USE_SOURCE as default option to LaunchConfigurationTemplate bootMode
    parameter.
  * api-change:``networkmonitor``: Updated the allowed monitorName length for CloudWatch Network
    Monitor.
- from version 1.32.79
  * api-change:``quicksight``: Adding IAMIdentityCenterInstanceArn parameter to
    CreateAccountSubscription
  * api-change:``resource-groups``: Added a new QueryErrorCode RESOURCE_TYPE_NOT_SUPPORTED that is
    returned by the ListGroupResources operation if the group query contains unsupported resource types.
  * api-change:``verifiedpermissions``: Adding BatchIsAuthorizedWithToken API which supports multiple
    authorization requests against a PolicyStore given a bearer token.
- from version 1.32.78
  * api-change:``b2bi``: Adding support for X12 5010 HIPAA EDI version and associated transaction
    sets.
  * api-change:``cleanrooms``: Feature: New schemaStatusDetails field to the existing Schema object
    that displays a status on Schema API responses to show whether a schema is queryable or not. New
    BatchGetSchemaAnalysisRule API to retrieve multiple schemaAnalysisRules using a single API call.
  * api-change:``ec2``: Amazon EC2 G6 instances powered by NVIDIA L4 Tensor Core GPUs can be used for
    a wide range of graphics-intensive and machine learning use cases. Gr6 instances also feature
    NVIDIA L4 GPUs and can be used for graphics workloads with higher memory requirements.
  * api-change:``emr-containers``: This release adds support for integration with EKS AccessEntry
    APIs to enable automatic Cluster Access for EMR on EKS.
  * api-change:``ivs``: API update to include an SRT ingest endpoint and passphrase for all channels.
  * api-change:``verifiedpermissions``: Adds GroupConfiguration field to Identity Source API's
- from version 1.32.77
  * api-change:``cleanroomsml``: The release includes a public SDK for AWS Clean Rooms ML APIs,
    making them globally available to developers worldwide.
  * api-change:``cloudformation``: This release would return a new field - PolicyAction in
    cloudformation's existed DescribeChangeSetResponse, showing actions we are going to apply on the
    physical resource (e.g., Delete, Retain) according to the user's template
  * api-change:``datazone``: This release supports the feature of dataQuality to enrich asset with
    dataQualityResult in Amazon DataZone.
  * api-change:``docdb``: This release adds Global Cluster Switchover capability which enables you to
    change your global cluster's primary AWS Region, the region that serves writes, while preserving
    the replication between all regions in the global cluster.
  * api-change:``groundstation``: This release adds visibilityStartTime and visibilityEndTime to
    DescribeContact and ListContacts responses.
  * api-change:``lambda``: Add Ruby 3.3 (ruby3.3) support to AWS Lambda
  * api-change:``medialive``: Cmaf Ingest outputs are now supported in Media Live
  * api-change:``medical-imaging``: SearchImageSets API now supports following enhancements -
    Additional support for searching on UpdatedAt and SeriesInstanceUID - Support for searching
    existing filters between dates/times - Support for sorting the search result by
    Ascending/Descending - Additional parameters returned in the response
  * api-change:``transfer``: Add ability to specify Security Policies for SFTP Connectors
- from version 1.32.76
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``glue``: Adding View related fields to responses of read-only Table APIs.
  * api-change:``ivschat``: Doc-only update. Changed "Resources" to "Key Concepts" in docs and
    updated text.
  * api-change:``rolesanywhere``: This release increases the limit on the roleArns request parameter
    for the *Profile APIs that support it. This parameter can now take up to 250 role ARNs.
  * api-change:``securityhub``: Documentation updates for AWS Security Hub
- from version 1.32.75
  * api-change:``cloudwatch``: This release adds support for CloudWatch Anomaly Detection on
    cross-account metrics. SingleMetricAnomalyDetector and MetricDataQuery inputs to Anomaly Detection
    APIs now take an optional AccountId field.
  * api-change:``datazone``: This release supports the feature of AI recommendations for descriptions
    to enrich the business data catalog in Amazon DataZone.
  * api-change:``deadline``: AWS Deadline Cloud is a new fully managed service that helps customers
    set up, deploy, and scale rendering projects in minutes, so they can improve the efficiency of
    their rendering pipelines and take on more projects.
  * api-change:``emr``: This release fixes a broken link in the documentation.
  * api-change:``lightsail``: This release adds support to upgrade the TLS version of the
    distribution.
- from version 1.32.74
  * api-change:``b2bi``: Supporting new EDI X12 transaction sets for X12 versions 4010, 4030, and
    5010.
  * api-change:``codebuild``: Add new fleet status code for Reserved Capacity.
  * api-change:``codeconnections``: Duplicating the CodeStar Connections service into the new,
    rebranded AWS CodeConnections service.
  * api-change:``internetmonitor``: This release adds support to allow customers to track cross
    account monitors through ListMonitor, GetMonitor, ListHealthEvents, GetHealthEvent, StartQuery APIs.
  * api-change:``iotwireless``: Add support for retrieving key historical and live metrics for
    LoRaWAN devices and gateways
  * api-change:``marketplace-catalog``: This release enhances the ListEntities API to support
    ResaleAuthorizationId filter and sort for OfferEntity in the request and the addition of a
    ResaleAuthorizationId field in the response of OfferSummary.
  * api-change:``neptune-graph``: Add the new API Start-Import-Task for Amazon Neptune Analytics.
  * api-change:``sagemaker``: This release adds support for custom images for the CodeEditor App on
    SageMaker Studio
  * enhancement:``s3``: Add parameter to validate source and destination S3 URIs to the ``mv``
    command.
- from version 1.32.73
  * api-change:``codecatalyst``: This release adds support for understanding pending changes to
    subscriptions by including two new response parameters for the GetSubscription API for Amazon
    CodeCatalyst.
  * api-change:``compute-optimizer``: This release enables AWS Compute Optimizer to analyze and
    generate recommendations with a new customization preference, Memory Utilization.
  * api-change:``ec2``: Amazon EC2 C7gd, M7gd and R7gd metal instances with up to 3.8 TB of local
    NVMe-based SSD block-level storage have up to 45%% improved real-time NVMe storage performance than
    comparable Graviton2-based instances.
  * api-change:``eks``: Add multiple customer error code to handle customer caused failure when
    managing EKS node groups
  * api-change:``guardduty``: Add EC2 support for GuardDuty Runtime Monitoring auto management.
  * api-change:``neptune-graph``: Update ImportTaskCancelled waiter to evaluate task state correctly
    and minor documentation changes.
  * api-change:``oam``: This release adds support for sharing AWS::InternetMonitor::Monitor resources.
  * api-change:``quicksight``: Amazon QuickSight: Adds support for setting up VPC Endpoint
    restrictions for accessing QuickSight Website.
- from version 1.32.72
  * api-change:``batch``: This feature allows AWS Batch to support configuration of imagePullSecrets
    and allowPrivilegeEscalation for jobs running on EKS
  * api-change:``bedrock-agent``: This changes introduces metadata documents statistics and also
    updates the documentation for bedrock agent.
  * api-change:``bedrock-agent-runtime``: This release introduces filtering support on Retrieve and
    RetrieveAndGenerate APIs.
  * api-change:``elasticache``: Added minimum capacity to  Amazon ElastiCache Serverless. This
    feature allows customer to ensure minimum capacity even without current load
  * api-change:``secretsmanager``: Documentation updates for Secrets Manager
- from version 1.32.71
  * api-change:``bedrock-agent-runtime``: This release adds support to customize prompts sent through
    the RetrieveAndGenerate API in Agents for Amazon Bedrock.
  * api-change:``ce``: Adds support for backfill of cost allocation tags, with new
    StartCostAllocationTagBackfill and ListCostAllocationTagBackfillHistory API.
  * api-change:``ec2``: Documentation updates for Elastic Compute Cloud (EC2).
  * api-change:``ecs``: This is a documentation update for Amazon ECS.
  * api-change:``finspace``: Add new operation delete-kx-cluster-node and add status parameter to
    list-kx-cluster-node operation.
- from version 1.32.70
  * api-change:``codebuild``: Supporting GitLab and GitLab Self Managed as source types in AWS
    CodeBuild.
  * api-change:``ec2``: Added support for ModifyInstanceMetadataDefaults and
    GetInstanceMetadataDefaults to set Instance Metadata Service account defaults
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``emr-containers``: This release increases the number of supported job template
    parameters from 20 to 100.
  * api-change:``globalaccelerator``: AWS Global Accelerator now supports cross-account sharing for
    bring your own IP addresses.
  * api-change:``medialive``: Exposing TileMedia H265 options
  * api-change:``sagemaker``: Introduced support for the following new instance types on SageMaker
    Studio for JupyterLab and CodeEditor applications: m6i, m6id, m7i, c6i, c6id, c7i, r6i, r6id, r7i,
    and p5
- from version 1.32.69
  * api-change:``firehose``: Updates Amazon Firehose documentation for message regarding Enforcing
    Tags IAM Policy.
  * api-change:``kendra``: Documentation update, March 2024. Corrects some docs for Amazon Kendra.
  * api-change:``pricing``: Add ResourceNotFoundException to ListPriceLists and GetPriceListFileUrl
    APIs
  * api-change:``rolesanywhere``: This release relaxes constraints on the durationSeconds request
    parameter for the *Profile APIs that support it. This parameter can now take on values that go up
    to 43200.
  * api-change:``securityhub``: Added new resource detail object to ASFF, including resource for
    LastKnownExploitAt
- from version 1.32.68
  * api-change:``codeartifact``: This release adds Package groups to CodeArtifact so you can more
    conveniently configure package origin controls for multiple packages.
- from version 1.32.67
  * api-change:``accessanalyzer``: This release adds support for policy validation and external
    access findings for DynamoDB tables and streams. IAM Access Analyzer helps you author functional
    and secure resource-based policies and identify cross-account access. Updated service API,
    documentation, and paginators.
  * api-change:``codebuild``: This release adds support for new webhook events (RELEASED and
    PRERELEASED) and filter types (TAG_NAME and RELEASE_NAME).
  * api-change:``connect``: This release updates the *InstanceStorageConfig APIs to support a new
    ResourceType: REAL_TIME_CONTACT_ANALYSIS_CHAT_SEGMENTS. Use this resource type to enable streaming
    for real-time analysis of chat contacts and to associate a Kinesis stream where real-time analysis
    chat segments will be published.
  * api-change:``dynamodb``: This release introduces 3 new APIs ('GetResourcePolicy',
    'PutResourcePolicy' and 'DeleteResourcePolicy') and modifies the existing 'CreateTable' API for the
    resource-based policy support. It also modifies several APIs to accept a 'TableArn' for the
    'TableName' parameter.
  * api-change:``managedblockchain-query``: AMB Query: update GetTransaction to include transactionId
    as input
  * api-change:``savingsplans``: Introducing the Savings Plans Return feature enabling customers to
    return their Savings Plans within 7 days of purchase.
- from version 1.32.66
  * api-change:``cloudformation``: Documentation update, March 2024. Corrects some formatting.
  * api-change:``ec2``: This release adds the new DescribeMacHosts API operation for getting
    information about EC2 Mac Dedicated Hosts. Users can now see the latest macOS versions that their
    underlying Apple Mac can support without needing to be updated.
  * api-change:``finspace``: Adding new attributes readWrite and onDemand to dataview models for
    Database Maintenance operations.
  * api-change:``logs``: Update LogSamples field in Anomaly model to be a list of LogEvent
  * api-change:``managedblockchain-query``: Introduces a new API for Amazon Managed Blockchain Query:
    ListFilteredTransactionEvents.
- from version 1.32.65
  * api-change:``cloudformation``: This release supports for a new API
    ListStackSetAutoDeploymentTargets, which provider auto-deployment configuration as a describable
    resource. Customers can now view the specific combinations of regions and OUs that are being
    auto-deployed.
  * api-change:``kms``: Adds the ability to use the default policy name by omitting the policyName
    parameter in calls to PutKeyPolicy and GetKeyPolicy
  * api-change:``mediatailor``: This release adds support to allow customers to show different
    content within a channel depending on metadata associated with the viewer.
  * api-change:``rds``: This release launches the ModifyIntegration API and support for data
    filtering for zero-ETL Integrations.
  * api-change:``s3``: Fix two issues with response root node names.
  * api-change:``timestream-query``: Documentation updates, March 2024
- from version 1.32.64
  * api-change:``backup``: This release introduces a boolean attribute ManagedByAWSBackupOnly as part
    of ListRecoveryPointsByResource api to filter the recovery points based on ownership. This
    attribute can be used to filter out the recovery points protected by AWSBackup.
  * api-change:``codebuild``: AWS CodeBuild now supports overflow behavior on Reserved Capacity.
  * api-change:``connect``: This release adds Hierarchy based Access Control fields to Security
    Profile public APIs and adds support for UserAttributeFilter to SearchUsers API.
  * api-change:``ec2``: Add media accelerator and neuron device information on the describe instance
    types API.
  * api-change:``kinesisanalyticsv2``: Support for Flink 1.18 in Managed Service for Apache Flink
  * api-change:``s3``: Documentation updates for Amazon S3.
  * api-change:``sagemaker``: Adds m6i, m6id, m7i, c6i, c6id, c7i, r6i r6id, r7i, p5 instance type
    support to Sagemaker Notebook Instances and miscellaneous wording fixes for previous Sagemaker
    documentation.
  * api-change:``workspaces-thin-client``: Removed unused parameter kmsKeyArn from UpdateDeviceRequest
- from version 1.32.63
  * api-change:``amplify``: Documentation updates for Amplify. Identifies the APIs available only to
    apps created using Amplify Gen 1.
  * api-change:``ec2-instance-connect``: This release includes a new exception type
    "SerialConsoleSessionUnsupportedException" for SendSerialConsoleSSHPublicKey API.
  * api-change:``elbv2``: This release allows you to configure HTTP client keep-alive duration for
    communication between clients and Application Load Balancers.
  * api-change:``fis``: This release adds support for previewing target resources before running a
    FIS experiment. It also adds resource ARNs for actions, experiments, and experiment templates to
    API responses.
  * api-change:``rds``: Updates Amazon RDS documentation for EBCDIC collation for RDS for Db2.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``timestream-influxdb``: This is the initial SDK release for Amazon Timestream for
    InfluxDB. Amazon Timestream for InfluxDB is a new time-series database engine that makes it easy
    for application developers and DevOps teams to run InfluxDB databases on AWS for near real-time
    time-series applications using open source APIs.
- from version 1.32.62
  * api-change:``ivs-realtime``: adds support for multiple new composition layout configuration
    options (grid, pip)
  * api-change:``kinesisanalyticsv2``: Support new RuntimeEnvironmentUpdate parameter within
    UpdateApplication API allowing callers to change the Flink version upon which their application
    runs.
  * api-change:``s3``: This release makes the default option for S3 on Outposts request signing to
    use the SigV4A algorithm when using AWS Common Runtime (CRT).
- from version 1.32.61
  * api-change:``cloudformation``: CloudFormation documentation update for March, 2024
  * api-change:``connect``: This release increases MaxResults limit to 500 in request for
    SearchUsers, SearchQueues and SearchRoutingProfiles APIs of Amazon Connect.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``kafka``: Added support for specifying the starting position of topic replication in
    MSK-Replicator.
  * api-change:``ssm``: March 2024 doc-only updates for Systems Manager.
- from version 1.32.60
  * api-change:``codestar-connections``: Added a sync configuration enum to disable publishing of
    deployment status to source providers (PublishDeploymentStatus). Added a sync configuration enum
    (TriggerStackUpdateOn) to only trigger changes.
  * api-change:``elasticache``: Revisions to API text that are now to be carried over to SDK text,
    changing usages of "SFO" in code examples to "us-west-1", and some other typos.
  * api-change:``mediapackagev2``: This release enables customers to safely update their MediaPackage
    v2 channel groups, channels and origin endpoints using entity tags.
- from version 1.32.59
  * api-change:``batch``: This release adds JobStateTimeLimitActions setting to the Job Queue API. It
    allows you to configure an action Batch can take for a blocking job in front of the queue after the
    defined period of time. The new parameter applies for ECS, EKS, and FARGATE Job Queues.
  * api-change:``bedrock-agent-runtime``: Documentation update for Bedrock Runtime Agent
  * api-change:``cloudtrail``: Added exceptions to CreateTrail, DescribeTrails, and
    ListImportFailures APIs.
  * api-change:``codebuild``: This release adds support for a new webhook event: PULL_REQUEST_CLOSED.
  * api-change:``cognito-idp``: Add ConcurrentModificationException to SetUserPoolMfaConfig
  * api-change:``guardduty``: Add RDS Provisioned and Serverless Usage types
  * api-change:``transfer``: Added DES_EDE3_CBC to the list of supported encryption algorithms for
    messages sent with an AS2 connector.
- from version 1.32.58
  * api-change:``appconfig``: AWS AppConfig now supports dynamic parameters, which enhance the
    functionality of AppConfig Extensions by allowing you to provide parameter values to your
    Extensions at the time you deploy your configuration.
  * api-change:``ec2``: This release adds an optional parameter to RegisterImage and CopyImage APIs
    to support tagging AMIs at the time of creation.
  * api-change:``grafana``: Adds support for the new GrafanaToken as part of the Amazon Managed
    Grafana Enterprise plugins upgrade to associate your AWS account with a Grafana Labs account.
  * api-change:``lambda``: Documentation updates for AWS Lambda
  * api-change:``payment-cryptography-data``: AWS Payment Cryptography EMV Decrypt Feature  Release
  * api-change:``rds``: Updates Amazon RDS documentation for io2 storage for Multi-AZ DB clusters
  * api-change:``snowball``: Doc-only update for change to EKS-Anywhere ordering.
  * api-change:``wafv2``: You can increase the max request body inspection size for some regional
    resources. The size setting is in the web ACL association config. Also, the
    AWSManagedRulesBotControlRuleSet EnableMachineLearning setting now takes a Boolean instead of a
    primitive boolean type, for languages like Java.
  * api-change:``workspaces``: Added note for user decoupling
- from version 1.32.57
  * api-change:``dynamodb``: Doc only updates for DynamoDB documentation
  * api-change:``imagebuilder``: Add PENDING status to Lifecycle Execution resource status. Add
    StartTime and EndTime to ListLifecycleExecutionResource API response.
  * api-change:``mwaa``: Amazon MWAA adds support for Apache Airflow v2.8.1.
  * api-change:``rds``: Updated the input of CreateDBCluster and ModifyDBCluster to support setting
    CA certificates. Updated the output of DescribeDBCluster to show current CA certificate setting
    value.
  * api-change:``redshift``: Update for documentation only. Covers port ranges, definition updates
    for data sharing, and definition updates to cluster-snapshot documentation.
  * api-change:``verifiedpermissions``: Deprecating details in favor of configuration for
    GetIdentitySource and ListIdentitySources APIs.
- from version 1.32.56
  * api-change:``apigateway``: Documentation updates for Amazon API Gateway
  * api-change:``chatbot``: Minor update to documentation.
  * api-change:``organizations``: This release contains an endpoint addition
  * api-change:``sesv2``: Adds support for providing custom headers within SendEmail and
    SendBulkEmail for SESv2.
- from version 1.32.55
  * api-change:``cloudformation``: Add DetailedStatus field to DescribeStackEvents and DescribeStacks
    APIs
  * api-change:``fsx``: Added support for creating FSx for NetApp ONTAP file systems with up to 12 HA
    pairs, delivering up to 72 GB/s of read throughput and 12 GB/s of write throughput.
  * api-change:``organizations``: Documentation update for AWS Organizations
- from version 1.32.54
  * api-change:``accessanalyzer``: Fixed a typo in description field.
  * api-change:``autoscaling``: With this release, Amazon EC2 Auto Scaling groups, EC2 Fleet, and
    Spot Fleet improve the default price protection behavior of attribute-based instance type selection
    of Spot Instances, to consistently select from a wide range of instance types.
  * api-change:``ec2``: With this release, Amazon EC2 Auto Scaling groups, EC2 Fleet, and Spot Fleet
    improve the default price protection behavior of attribute-based instance type selection of Spot
    Instances, to consistently select from a wide range of instance types.
- from version 1.32.53
  * api-change:``docdb-elastic``: Launched Elastic Clusters Readable Secondaries, Start/Stop,
    Configurable Shard Instance count, Automatic Backups and Snapshot Copying
  * api-change:``eks``: Added support for new AL2023 AMIs to the supported AMITypes.
  * api-change:``lexv2-models``: This release makes AMAZON.QnAIntent generally available in Amazon
    Lex. This generative AI feature leverages large language models available through Amazon Bedrock to
    automate frequently asked questions (FAQ) experience for end-users.
  * api-change:``migrationhuborchestrator``: Adds new CreateTemplate, UpdateTemplate and
    DeleteTemplate APIs.
  * api-change:``quicksight``: TooltipTarget for Combo chart visuals; ColumnConfiguration limit
    increase to 2000; Documentation Update
  * api-change:``sagemaker``: Adds support for ModelDataSource in Model Packages to support unzipped
    models. Adds support to specify SourceUri for models which allows registration of models without
    mandating a container for hosting. Using SourceUri, customers can decouple the model from hosting
    information during registration.
  * api-change:``securitylake``: Add capability to update the Data Lake's MetaStoreManager Role in
    order to perform required data lake updates to use Iceberg table format in their data lake or
    update the role for any other reason.
- from version 1.32.52
  * api-change:``batch``: This release adds Batch support for configuration of multicontainer jobs in
    ECS, Fargate, and EKS. This support is available for all types of jobs, including both array jobs
    and multi-node parallel jobs.
  * api-change:``bedrock-agent-runtime``: This release adds support to override search strategy
    performed by the Retrieve and RetrieveAndGenerate APIs for Amazon Bedrock Agents
  * api-change:``ce``: This release introduces the new API 'GetApproximateUsageRecords', which
    retrieves estimated usage records for hourly granularity or resource-level data at daily
    granularity.
  * api-change:``ec2``: This release increases the range of MaxResults for
    GetNetworkInsightsAccessScopeAnalysisFindings to 1,000.
  * api-change:``iot``: This release reduces the maximum results returned per query invocation from
    500 to 100 for the SearchIndex API. This change has no implications as long as the API is invoked
    until the nextToken is NULL.
  * api-change:``wafv2``: AWS WAF now supports configurable time windows for request aggregation with
    rate-based rules. Customers can now select time windows of 1 minute, 2 minutes or 10 minutes, in
    addition to the previously supported 5 minutes.
- from version 1.32.51
  * api-change:``amplifyuibuilder``: We have added the ability to tag resources after they are created
- from version 1.32.50
  * api-change:``apigateway``: Documentation updates for Amazon API Gateway.
  * api-change:``drs``: Added volume status to DescribeSourceServer replicated volumes.
  * api-change:``kafkaconnect``: Adds support for tagging, with new TagResource, UntagResource and
    ListTagsForResource APIs to manage tags and updates to existing APIs to allow tag on create. This
    release also adds support for the new DeleteWorkerConfiguration API.
  * api-change:``rds``: This release adds support for gp3 data volumes for Multi-AZ DB Clusters.
- from version 1.32.49
  * api-change:``appsync``: Documentation only updates for AppSync
  * api-change:``qldb``: Clarify possible values for KmsKeyArn and EncryptionDescription.
  * api-change:``rds``: Add pattern and length based validations for DBShardGroupIdentifier
  * api-change:``rum``: Doc-only update for new RUM metrics that were added
- from version 1.32.48
  * api-change:``internetmonitor``: This release adds IPv4 prefixes to health events
  * api-change:``kinesisvideo``: Increasing NextToken parameter length restriction for List APIs from
    512 to 1024.
- from version 1.32.47
  * api-change:``iotevents``: Increase the maximum length of descriptions for Inputs, Detector
    Models, and Alarm Models
  * api-change:``lookoutequipment``: This release adds a field exposing model quality to read APIs
    for models. It also adds a model quality field to the API response when creating an inference
    scheduler.
  * api-change:``medialive``: MediaLive now supports the ability to restart pipelines in a running
    channel.
  * api-change:``ssm``: This release adds support for sharing Systems Manager parameters with other
    AWS accounts.
- from version 1.32.46
  * api-change:``dynamodb``: Publishing quick fix for doc only update.
  * api-change:``firehose``: This release updates a few Firehose related APIs.
  * api-change:``lambda``: Add .NET 8 (dotnet8) Runtime support to AWS Lambda.
- from version 1.32.45
  * api-change:``amplify``: This release contains API changes that enable users to configure their
    Amplify domains with their own custom SSL/TLS certificate.
  * api-change:``chatbot``: This release adds support for AWS Chatbot. You can now monitor, operate,
    and troubleshoot your AWS resources with interactive ChatOps using the AWS SDK.
  * api-change:``config``: Documentation updates for the AWS Config CLI
  * api-change:``ivs``: Changed description for latencyMode in Create/UpdateChannel and
    Channel/ChannelSummary.
  * api-change:``keyspaces``: Documentation updates for Amazon Keyspaces
  * api-change:``mediatailor``: MediaTailor: marking #AdBreak.OffsetMillis as required.
- from version 1.32.44
  * api-change:``connectparticipant``: Doc only update to GetTranscript API reference guide to inform
    users about presence of events in the chat transcript.
  * api-change:``emr``: adds fine grained control over Unhealthy Node Replacement to Amazon
    ElasticMapReduce
  * api-change:``firehose``: This release adds support for Data Message Extraction for decompressed
    CloudWatch logs, and to use a custom file extension or time zone for S3 destinations.
  * api-change:``lambda``: Documentation-only updates for Lambda to clarify a number of existing
    actions and properties.
  * api-change:``rds``: Doc only update for a valid option in DB parameter group
  * api-change:``sns``: This release marks phone numbers as sensitive inputs.
- from version 1.32.43
  * api-change:``artifact``: This is the initial SDK release for AWS Artifact. AWS Artifact provides
    on-demand access to compliance and third-party compliance reports. This release includes access to
    List and Get reports, along with their metadata. This release also includes access to AWS Artifact
    notifications settings.
  * api-change:``codepipeline``: Add ability to override timeout on action level.
  * api-change:``detective``: Doc only updates for content enhancement
  * api-change:``guardduty``: Marked fields IpAddressV4, PrivateIpAddress, Email as Sensitive.
  * api-change:``healthlake``: This release adds a new response parameter, JobProgressReport, to the
    DescribeFHIRImportJob and ListFHIRImportJobs API operation. JobProgressReport provides details on
    the progress of the import job on the server.
  * api-change:``opensearch``: Adds additional supported instance types.
  * api-change:``polly``: Amazon Polly adds 1 new voice - Burcu (tr-TR)
  * api-change:``sagemaker``: This release adds a new API UpdateClusterSoftware for SageMaker
    HyperPod. This API allows users to patch HyperPod clusters with latest platform softwares.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.42
  * api-change:``controltower``: Adds support for new Baseline and EnabledBaseline APIs for
    automating multi-account governance.
  * api-change:``lookoutequipment``: This feature allows customers to see pointwise model diagnostics
    results for their models.
  * api-change:``qbusiness``: This release adds the metadata-boosting feature, which allows customers
    to easily fine-tune the underlying ranking of retrieved RAG passages in order to optimize Q&A
    answer relevance. It also adds new feedback reasons for the PutFeedback API.
- from version 1.32.41
  * api-change:``lightsail``: This release adds support to upgrade the major version of a database.
  * api-change:``marketplace-catalog``: AWS Marketplace Catalog API now supports setting intent on
    requests
  * api-change:``resource-explorer-2``: Resource Explorer now uses newly supported IPv4
    'amazonaws.com' endpoints by default.
  * api-change:``securitylake``: Documentation updates for Security Lake
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.40
  * api-change:``appsync``: Adds support for new options on GraphqlAPIs, Resolvers and  Data Sources
    for emitting Amazon CloudWatch metrics for enhanced monitoring of AppSync APIs.
  * api-change:``cloudwatch``: Update cloudwatch command to latest version
  * api-change:``neptune-graph``: Adding a new option "parameters" for data plane api ExecuteQuery to
    support running parameterized query via SDK.
  * api-change:``route53domains``: This release adds bill contact support for RegisterDomain,
    TransferDomain, UpdateDomainContact and GetDomainDetail API.
- from version 1.32.39
  * api-change:``amp``: Overall documentation updates.
  * api-change:``batch``: This feature allows Batch to support configuration of repository
    credentials for jobs running on ECS
  * api-change:``braket``: Creating a job will result in DeviceOfflineException when using an offline
    device, and DeviceRetiredException when using a retired device.
  * api-change:``cost-optimization-hub``: Adding includeMemberAccounts field to the response of
    ListEnrollmentStatuses API.
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``iot``: This release allows AWS IoT Core users to enable Online Certificate Status
    Protocol (OCSP) Stapling for TLS X.509 Server Certificates when creating and updating AWS IoT
    Domain Configurations with Custom Domain.
  * api-change:``pricing``: Add Throttling Exception to all APIs.
- from version 1.32.38
  * api-change:``codepipeline``: Add ability to execute pipelines with new parallel & queued
    execution modes and add support for triggers with filtering on branches and file paths.
  * api-change:``quicksight``: General Interactions for Visuals; Waterfall Chart Color Configuration;
    Documentation Update
  * api-change:``workspaces``: This release introduces User-Decoupling feature. This feature allows
    Workspaces Core customers to provision workspaces without providing users. CreateWorkspaces and
    DescribeWorkspaces APIs will now take a new optional parameter "WorkspaceName".
- from version 1.32.37
  * api-change:``datasync``: AWS DataSync now supports manifests for specifying files or objects to
    transfer.
  * api-change:``lexv2-models``: Update lexv2-models command to latest version
  * api-change:``redshift``: LisRecommendations API to fetch Amazon Redshift Advisor recommendations.
- from version 1.32.36
  * api-change:``appsync``: Support for environment variables in AppSync GraphQL APIs
  * api-change:``ecs``: This release is a documentation only update to address customer issues.
  * api-change:``es``: This release adds clear visibility to the customers on the changes that they
    make on the domain.
  * api-change:``logs``: This release adds a new field, logGroupArn, to the response of the
    logs:DescribeLogGroups action.
  * api-change:``opensearch``: This release adds clear visibility to the customers on the changes
    that they make on the domain.
  * api-change:``wafv2``: You can now delete an API key that you've created for use with your CAPTCHA
    JavaScript integration API.
- from version 1.32.35
  * api-change:``glue``: Introduce Catalog Encryption Role within Glue Data Catalog Settings.
    Introduce SASL/PLAIN as an authentication method for Glue Kafka connections
  * api-change:``workspaces``: Added definitions of various WorkSpace states
- from version 1.32.34
  * api-change:``dynamodb``: Any number of users can execute up to 50 concurrent restores (any type
    of restore) in a given account.
  * api-change:``sagemaker``: Amazon SageMaker Canvas adds GenerativeAiSettings support for
    CanvasAppSettings.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.33
  * api-change:``cognito-idp``: Added CreateIdentityProvider and UpdateIdentityProvider details for
    new SAML IdP features
  * api-change:``ivs``: This release introduces a new resource Playback Restriction Policy which can
    be used to geo-restrict or domain-restrict channel stream playback when associated with a channel.
    New APIs to support this resource were introduced in the form of Create/Delete/Get/Update/List.
  * api-change:``managedblockchain-query``: This release adds support for transactions that have not
    reached finality. It also removes support for the status property from the response of the
    GetTransaction operation. You can use the confirmationStatus and executionStatus properties to
    determine the status of the transaction.
  * api-change:``mediaconvert``: This release includes support for broadcast-mixed audio description
    tracks.
  * api-change:``neptune-graph``: Adding new APIs in SDK for Amazon Neptune Analytics. These APIs
    include operations to execute, cancel, list queries and get the graph summary.
- from version 1.32.32
  * api-change:``cloudformation``: CloudFormation IaC generator allows you to scan existing resources
    in your account and select resources to generate a template for a new or existing CloudFormation
    stack.
  * api-change:``elbv2``: Update elbv2 command to latest version
  * api-change:``glue``: Update page size limits for GetJobRuns and GetTriggers APIs.
  * api-change:``ssm``: This release adds an optional Duration parameter to StateManager
    Associations. This allows customers to specify how long an apply-only-on-cron association execution
    should run. Once the specified Duration is out all the ongoing cancellable commands or automations
    are cancelled.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Wed Mar 13 2024 Robert Schweikert <rjschwei@suse.com>
- Reconfigure the spec file support builds better in Factory and SLE
  supporting different Python interpreter versions
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Jan 31 2024 Robert Schweikert <rjschwei@suse.com>
- Switch to Python 3.11 build in SLE 15 SP4 and openSUSE Leap 15.4 and
  later (jsc#PCT-371)
- Switch to wheel build
- Update to version 1.32.31
  * Forward port ac_update-docutils.patch
  * api-change:``datazone``: Add new skipDeletionCheck to DeleteDomain. Add
    new skipDeletionCheck to DeleteProject which also automatically deletes
    dependent objects
  * api-change:``route53``: Update the SDKs for text changes in the APIs.
- From 1.32.30
  * api-change:``autoscaling``: EC2 Auto Scaling customers who use attribute
    based instance-type selection can now intuitively define their Spot
    instances price protection limit as a percentage of the lowest priced
    On-Demand instance type.
  * api-change:``comprehend``: Comprehend PII analysis now supports Spanish
    input documents.
  * api-change:``ec2``: EC2 Fleet customers who use attribute based
    instance-type selection can now intuitively define their Spot instances
    price protection limit as a percentage of the lowest priced On-Demand
    instance type.
  * api-change:``mwaa``: This release adds MAINTENANCE environment status for
    Amazon MWAA environments.
  * api-change:``rds``: Introduced support for the
    InsufficientDBInstanceCapacityFault error in the RDS
    RestoreDBClusterFromSnapshot and RestoreDBClusterToPointInTime API methods.
    This provides enhanced error handling, ensuring a more robust experience.
  * api-change:``snowball``: Modified description of createaddress to include
    direction to add path when providing a JSON file.
- From 1.32.29
  * api-change:``connect``: Update list and string length limits for predefined
    attributes.
  * api-change:``inspector2``: This release adds ECR container image scanning
    based on their lastRecordedPullTime.
  * api-change:``sagemaker``: Amazon SageMaker Automatic Model Tuning now
    provides an API to programmatically delete tuning jobs.
- From 1.32.28
  * api-change:``acm-pca``: AWS Private CA now supports an option to omit the
    CDP extension from issued certificates, when CRL revocation is enabled.
  * api-change:``lightsail``: This release adds support for IPv6-only instance
    plans.
- From 1.32.27
  * api-change:``ec2``: Introduced a new clientToken request parameter on
    CreateNetworkAcl and CreateRouteTable APIs. The clientToken parameter
    allows idempotent operations on the APIs.
  * api-change:``ecs``: Documentation updates for Amazon ECS.
  * api-change:``outposts``: DeviceSerialNumber parameter is now optional in
    StartConnection API
  * api-change:``rds``: This release adds support for Aurora Limitless Database.
  * api-change:``storagegateway``: Add DeprecationDate and SoftwareVersion to
    response of ListGateways.
- From 1.32.26
  * api-change:``inspector2``: This release adds support for CIS scans on EC2
    instances.
- From 1.32.25
  * bugfix:``s3 sync``: Disable S3 Express support for s3 sync command
- From 1.32.24
  * api-change:``appconfigdata``: Fix FIPS Endpoints in aws-us-gov.
  * api-change:``cloud9``: Doc-only update around removing AL1 from list of
    available AMIs for Cloud9
  * api-change:``cloudfront-keyvaluestore``: This release improves upon the
    DescribeKeyValueStore API by returning two additional fields, Status of the
    KeyValueStore and the FailureReason in case of failures during creation of
    KeyValueStore.
  * api-change:``connectcases``: This release adds the ability to view audit
    history on a case and introduces a new parameter, performedBy, for
    CreateCase and UpdateCase API's.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``ecs``: This release adds support for Transport Layer Security
    (TLS) and Configurable Timeout to ECS Service Connect. TLS facilitates
    privacy and data security for inter-service communications, while
    Configurable Timeout allows customized per-request timeout and idle timeout
    for Service Connect services.
  * api-change:``finspace``: Allow customer to set zip default through command
    line arguments.
  * api-change:``organizations``: Doc only update for quota increase change
  * api-change:``rds``: Introduced support for the
    InsufficientDBInstanceCapacityFault error in the RDS CreateDBCluster API
    method. This provides enhanced error handling, ensuring a more robust
    experience when creating database clusters with insufficient instance
    capacity.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.23
  * api-change:``athena``: Introducing new NotebookS3LocationUri parameter to
    Athena ImportNotebook API. Payload is no longer required and either Payload
    or NotebookS3LocationUri needs to be provided (not both) for a successful
    ImportNotebook API call. If both are provided, an InvalidRequestException
    will be thrown.
  * api-change:``codebuild``: Release CodeBuild Reserved Capacity feature
  * api-change:``dynamodb``: This release adds support for including
    ApproximateCreationDateTimePrecision configurations in
    EnableKinesisStreamingDestination API, adds the same as an optional field
    in the response of DescribeKinesisStreamingDestination, and adds support
    for a new UpdateKinesisStreamingDestination API.
  * api-change:``qconnect``: Increased Quick Response name max length to 100
- From 1.32.22
  * api-change:``b2bi``: Increasing TestMapping inputFileContent file size
    limit to 5MB and adding file size limit 250KB for TestParsing input file.
    This release also includes exposing InternalServerException for Tag APIs.
  * api-change:``cloudtrail``: This release adds a new API
    ListInsightsMetricData to retrieve metric data from CloudTrail Insights.
  * api-change:``connect``: GetMetricDataV2 now supports 3 groupings
  * api-change:``drs``: Removed invalid and unnecessary default values.
  * api-change:``firehose``: Allow support for Snowflake as a Kinesis Data
    Firehose delivery destination.
  * api-change:``sagemaker-featurestore-runtime``: Increase BatchGetRecord
    limits from 10 items to 100 items
- From 1.32.21
  * api-change:``dynamodb``: Updating note for enabling streams for UpdateTable.
  * api-change:``keyspaces``: This release adds support for Multi-Region
    Replication with provisioned tables, and Keyspaces auto scaling APIs
- From 1.32.20
  * api-change:``iot``: Revert release of LogTargetTypes
  * api-change:``iotfleetwise``: Updated APIs: SignalNodeType query parameter
    has been added to ListSignalCatalogNodesRequest and ListVehiclesResponse
    has been extended with attributes field.
  * api-change:``macie2``: This release adds support for analyzing Amazon S3
    objects that are encrypted using dual-layer server-side encryption with
    AWS KMS keys (DSSE-KMS). It also adds support for reporting DSSE-KMS
    details in statistics and metadata about encryption settings for S3 buckets
    and objects.
  * api-change:``payment-cryptography``: Provide an additional option for key
    exchange using RSA wrap/unwrap in addition to tr-34/tr-31 in ImportKey and
    ExportKey operations. Added new key usage (type)
    TR31_M1_ISO_9797_1_MAC_KEY, for use with Generate/VerifyMac dataplane
    operations  with ISO9797 Algorithm 1 MAC calculations.
  * api-change:``personalize-runtime``: Documentation updates for Amazon
    Personalize
  * api-change:``personalize``: Documentation updates for Amazon Personalize.
  * api-change:``rekognition``: This release adds ContentType and TaxonomyLevel
    attributes to DetectModerationLabels and GetMediaAnalysisJob API responses.
  * api-change:``securityhub``: Documentation updates for AWS Security Hub
- From 1.32.19
  * api-change:``sagemaker``: This release will have ValidationException thrown
    if certain invalid app types are provided. The release will also throw
    ValidationException if more than 10 account ids are provided in
    VpcOnlyTrustedAccounts.
- From 1.32.18
  * api-change:``connect``: Supervisor Barge for Chat is now supported through
    the MonitorContact API.
  * api-change:``connectparticipant``: Introduce new Supervisor participant
    role
  * api-change:``location``: Location SDK documentation update. Added missing
    fonts to the MapConfiguration data type. Updated note for the
    SubMunicipality property in the place data type.
  * api-change:``mwaa``: This Amazon MWAA feature release includes new fields
    in CreateWebLoginToken response model. The new fields IamIdentity and
    AirflowIdentity will let you match identifications, as the Airflow identity
    length is currently hashed to 64 characters.
  * api-change:``s3control``: S3 On Outposts team adds dualstack endpoints
    support for S3Control and S3Outposts API calls.
  * api-change:``supplychain``: This release includes APIs
    CreateBillOfMaterialsImportJob and GetBillOfMaterialsImportJob.
  * api-change:``transfer``: AWS Transfer Family now supports static IP
    addresses for SFTP & AS2 connectors and for async MDNs on AS2 servers.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.17
  * api-change:``ec2``: This release adds support for adding an
    ElasticBlockStorage volume configurations in ECS
    RunTask/StartTask/CreateService/UpdateService APIs. The configuration
    allows for attaching EBS volumes to ECS Tasks.
  * api-change:``ecs``: This release adds support for adding an
    ElasticBlockStorage volume configurations in ECS
    RunTask/StartTask/CreateService/UpdateService APIs. The configuration
    allows for attaching EBS volumes to ECS Tasks.
  * api-change:``events``: Update events command to latest version
  * api-change:``iot``: Add ConflictException to Update APIs of AWS IoT
    Software Package Catalog
  * api-change:``iotfleetwise``: The following dataTypes have been removed:
    CUSTOMER_DECODED_INTERFACE in NetworkInterfaceType;
    CUSTOMER_DECODED_SIGNAL_INFO_IS_NULL in SignalDecoderFailureReason;
    CUSTOMER_DECODED_SIGNAL_NETWORK_INTERFACE_INFO_IS_NULL in
    NetworkInterfaceFailureReason; CUSTOMER_DECODED_SIGNAL in SignalDecoderType
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``workspaces``: Added AWS Workspaces RebootWorkspaces
    API - Extended Reboot documentation update
- From 1.32.16
  * api-change:``connectcampaigns``: Minor pattern updates for Campaign and
    Dial Request API fields.
  * api-change:``location``: This release adds API support for custom layers
    for the maps service APIs: CreateMap, UpdateMap, DescribeMap.
  * api-change:``logs``: Add support for account level subscription filter
    policies to PutAccountPolicy, DescribeAccountPolicies, and
    DeleteAccountPolicy APIs. Additionally, PutAccountPolicy has been modified
    with new optional "selectionCriteria" parameter for resource selection.
  * api-change:``qconnect``: QueryAssistant and GetRecommendations will be
    discontinued starting June 1, 2024. To receive generative responses after
    March 1, 2024 you will need to create a new Assistant in the Connect
    console and integrate the Amazon Q in Connect JavaScript library
    (amazon-q-connectjs) into your applications.
  * api-change:``redshift-serverless``: Updates to ConfigParameter for RSS
    workgroup, removal of use_fips_ssl
  * api-change:``route53``: Route53 now supports geoproximity routing in AWS
    regions
  * api-change:``wisdom``: QueryAssistant and GetRecommendations will be
    discontinued starting June 1, 2024. To receive generative responses after
    March 1, 2024 you will need to create a new Assistant in the Connect
    console and integrate the Amazon Q in Connect JavaScript library
    (amazon-q-connectjs) into your applications.
- From 1.32.15
  * api-change:``codebuild``: Aws CodeBuild now supports new compute type
    BUILD_GENERAL1_XLARGE
  * api-change:``ec2``: Amazon EC2 R7iz bare metal instances are powered by
    custom 4th generation Intel Xeon Scalable processors.
  * api-change:``route53resolver``: This release adds support for query type
    configuration on firewall rules that enables customers for granular action
    (ALLOW, ALERT, BLOCK) by DNS query type.
- From 1.32.14
  * api-change:``connect``: Minor trait updates for User APIs
  * api-change:``kms``: Documentation updates for AWS Key Management Service
    (KMS).
  * api-change:``redshift-serverless``: use_fips_ssl and require_ssl parameter
    support for Workgroup, UpdateWorkgroup, and CreateWorkgroup
- From 1.32.13
  * api-change:``config``: Updated ResourceType enum with new resource types onboarded by AWS Config in November and December 2023.
  * api-change:``docdb``: Adding PerformanceInsightsEnabled and
    PerformanceInsightsKMSKeyId fields to DescribeDBInstances Response.
  * api-change:``ecs``: This release adds support for managed instance
    draining which facilitates graceful termination of Amazon ECS instances.
  * api-change:``es``: This release adds support for new or existing Amazon
    OpenSearch domains to enable TLS 1.3 or TLS 1.2 with perfect forward
    secrecy cipher suites for domain endpoints.
  * api-change:``lightsail``: This release adds support to set up an HTTPS
    endpoint on an instance.
  * api-change:``opensearch``: This release adds support for new or existing
    Amazon OpenSearch domains to enable TLS 1.3 or TLS 1.2 with perfect forward
    secrecy cipher suites for domain endpoints.
  * api-change:``sagemaker``: Adding support for provisioned throughput mode
    for SageMaker Feature Groups
  * api-change:``servicecatalog``: Added Idempotency token support to Service
    Catalog  AssociateServiceActionWithProvisioningArtifact,
    DisassociateServiceActionFromProvisioningArtifact, DeleteServiceAction API
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.12
  * api-change:``connect``: Amazon Connect, Contact Lens Evaluation API
    increase evaluation notes max length to 3072.
  * api-change:``mediaconvert``: This release includes video engine updates
    including HEVC improvements, support for ingesting VP9 encoded video in
    MP4 containers, and support for user-specified 3D LUTs.
- From 1.32.11
  * api-change:``apprunner``: AWS App Runner adds Python 3.11 and Node.js 18
    runtimes.
  * api-change:``location``: This release introduces a new parameter to
    bypasses an API key's expiry conditions and delete the key.
  * api-change:``quicksight``: Add LinkEntityArn support for different
    partitions; Add UnsupportedUserEditionException in UpdateDashboardLinks
    API; Add support for New Reader Experience Topics
- From 1.32.10
  * api-change:``codestar-connections``: New integration with the GitLab
    self-managed provider type.
  * api-change:``kinesis-video-archived-media``: NoDataRetentionException
    thrown when GetImages requested for a Stream that does not retain data
    (that is, has a DataRetentionInHours of 0).
  * api-change:``sagemaker``: Amazon SageMaker Studio now supports Docker
    access from within app container
- From 1.32.9
  * api-change:``emr``: Update emr command to latest version
- From 1.32.8
  * api-change:``iam``: Documentation updates for AWS Identity and Access
    Management (IAM).
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.7
  * api-change:``bedrock-agent``: Adding Claude 2.1 support to Bedrock Agents
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
  * api-change:``glue``: This release adds additional configurations for Query
    Session Context on the following APIs: GetUnfilteredTableMetadata,
    GetUnfilteredPartitionMetadata, GetUnfilteredPartitionsMetadata.
  * api-change:``lakeformation``: This release adds additional configurations
    on GetTemporaryGlueTableCredentials for Query Session Context.
  * api-change:``mediaconnect``: This release adds the DescribeSourceMetadata
    API. This API can be used to view the stream information of the flow's
    source.
  * api-change:``networkmonitor``: CloudWatch Network Monitor is a new service
    within CloudWatch that will help network administrators and operators
    continuously monitor network performance metrics such as round-trip-time
    and packet loss between their AWS-hosted applications and their on-premises
    locations.
  * api-change:``omics``: Provides minor corrections and an updated description
    of APIs.
  * api-change:``secretsmanager``: Update endpoint rules and examples.
- From 1.32.6
  * api-change:``amp``: This release updates Amazon Managed Service for
    Prometheus APIs to support customer managed KMS keys.
  * api-change:``appintegrations``: The Amazon AppIntegrations service adds
    DeleteApplication API for deleting applications, and updates APIs to
    support third party applications reacting to workspace events and make
    data requests to Amazon Connect for agent and contact events.
  * api-change:``bedrock-agent``: This release introduces Amazon Aurora as a
    vector store on Knowledge Bases for Amazon Bedrock
  * api-change:``codecommit``: AWS CodeCommit now supports customer managed
    keys from AWS Key Management Service. UpdateRepositoryEncryptionKey is
    added for updating the key configuration. CreateRepository, GetRepository,
    BatchGetRepositories are updated with new input or output parameters.
  * api-change:``connect``: Adds APIs to manage User Proficiencies and
    Predefined Attributes. Enhances StartOutboundVoiceContact API input.
    Introduces SearchContacts API. Enhances DescribeContact API. Adds an API to
    update Routing Attributes in QueuePriority and QueueTimeAdjustmentSeconds.
  * api-change:``medialive``: MediaLive now supports the ability to configure
    the audio that an AWS Elemental Link UHD device produces, when the device
    is configured as the source for a flow in AWS Elemental MediaConnect.
  * api-change:``neptune-graph``: Adds Waiters for successful creation and
    deletion of Graph, Graph Snapshot, Import Task and Private Endpoints for
    Neptune Analytics
  * api-change:``rds-data``: This release adds support for using RDS Data API
    with Aurora PostgreSQL Serverless v2 and provisioned DB clusters.
  * api-change:``rds``: This release adds support for using RDS Data API with
    Aurora PostgreSQL Serverless v2 and provisioned DB clusters.
  * api-change:``sagemaker``: Amazon SageMaker Training now provides model
    training container access for debugging purposes. Amazon SageMaker Search
    now provides the ability to use visibility conditions to limit resource
    access to a single domain or multiple domains.
- From 1.32.5
  * api-change:``appstream``: This release introduces configurable clipboard,
    allowing admins to specify the maximum length of text that can be copied by
    the users from their device to the remote session and vice-versa.
  * api-change:``eks``: Add support for cluster insights, new EKS capability
    that surfaces potentially upgrade impacting issues.
  * api-change:``guardduty``: This release 1) introduces a new API:
    GetOrganizationStatistics , and 2) adds a new UsageStatisticType
    TOP_ACCOUNTS_BY_FEATURE for GetUsageStatistics API
  * api-change:``managedblockchain-query``: Adding Confirmation Status and
    Execution Status to GetTransaction Response.
  * api-change:``mediatailor``: Adds the ability to configure time shifting on
    MediaTailor channels using the TimeShiftConfiguration field
  * api-change:``route53``: Amazon Route 53 now supports the Canada West
    (Calgary) Region (ca-west-1) for latency records, geoproximity records,
    and private DNS for Amazon VPCs in that region.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.4
  * api-change:``appsync``: This release adds additional configurations on
    GraphQL APIs for limits on query depth, resolver count, and introspection
  * api-change:``chime-sdk-meetings``: Add meeting features to specify a
    maximum camera resolution, a maximum content sharing resolution, and a
    maximum number of attendees for a given meeting.
  * api-change:``ec2``: Provision BYOIPv4 address ranges and advertise them by
    specifying the network border groups option in Los Angeles, Phoenix and
    Dallas AWS Local Zones.
  * api-change:``fsx``: Added support for FSx for OpenZFS on-demand data
    replication across AWS accounts and/or regions.Added the IncludeShared
    attribute for DescribeSnapshots.Added the CopyStrategy attribute for
    OpenZFSVolumeConfiguration.
  * api-change:``marketplace-catalog``: AWS Marketplace now supports a new API,
    BatchDescribeEntities, which returns metadata and content for multiple
    entities.
  * api-change:``rds``: RDS - The release adds two new APIs:
    DescribeDBRecommendations and ModifyDBRecommendation
- From 1.32.3
  * api-change:``cognito-idp``: Amazon Cognito now supports trigger versions
    that define the fields in the request sent to pre token generation Lambda
    triggers.
  * api-change:``eks``: Add support for EKS Cluster Access Management.
  * api-change:``quicksight``: A docs-only release to add missing entities to
    the API reference.
  * api-change:``route53resolver``: Add DOH protocols in resolver endpoints.
- From 1.32.2
  * enhancement:``cloudformation package``: Add support for intrinsic
    Fn:ForEach (fixes `#8075 <https://github.com/aws/aws-cli/issues/8075>`__)
  * api-change:``cloud9``: Updated Cloud9 API documentation for AL2023 release
  * api-change:``connect``: Adds relatedContactId field to
    StartOutboundVoiceContact API input. Introduces PauseContact API and
    ResumeContact API for Task contacts. Adds pause duration, number of pauses,
    timestamps for last paused and resumed events to DescribeContact API
    response. Adds new Rule type and new Rule action.
  * api-change:``connectcases``: Increase number of fields that can be included
    in CaseEventIncludedData from 50 to 200
  * api-change:``kms``: Documentation updates for AWS Key Management Service
  * api-change:``rds``: Updates Amazon RDS documentation by adding code examples
  * api-change:``sagemaker``: This release 1) introduces a new API:
    DeleteCompilationJob , and 2) adds InfraCheckConfig for Create/Describe
    training job API
- From 1.32.1
  * api-change:``appstream``: This release includes support for images of
    Windows Server 2022 platform.
  * api-change:``b2bi``: Documentation updates for AWS B2B Data Interchange
  * api-change:``billingconductor``: Billing Conductor is releasing a new API,
    GetBillingGroupCostReport, which provides the ability to retrieve/view the
    Billing Group Cost Report broken down by attributes for a specific billing
    group.
  * api-change:``connect``: This release adds support for more granular
    billing using tags (key:value pairs)
  * api-change:``controltower``: Documentation updates for AWS Control Tower.
  * api-change:``firehose``: This release, 1) adds configurable buffering hints
    for the Splunk destination, and 2) reduces the minimum configurable
    buffering interval for supported destinations
  * api-change:``gamelift``: Amazon GameLift adds the ability to add and update
    the game properties of active game sessions.
  * api-change:``iot``: This release adds the ability to self-manage
    certificate signing in AWS IoT Core fleet provisioning using the new
    certificate provider resource.
  * api-change:``neptune-graph``: This is the initial SDK release for Amazon
    Neptune Analytics
  * api-change:``opensearch``: Updating documentation for Amazon OpenSearch
    Service support for new zero-ETL integration with Amazon S3.
  * api-change:``quicksight``: Update Dashboard Links support;
    SingleAxisOptions support; Scatterplot Query limit support.
  * api-change:``workspaces``: Updated note to ensure customers understand
    running modes.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.0
  * feature:Python: End of support for Python 3.7
  * api-change:``drs``: Adding AgentVersion to SourceServer and
    RecoveryInstance structures
  * feature:Python: End of support for Python 3.7
- From 1.31.13
  * api-change:``imagebuilder``: This release adds the Image Workflows feature
    to give more flexibility and control over the image building and testing
    process.
  * api-change:``location``: This release 1)  adds sub-municipality field in
    Places API for searching and getting places information, and 2) allows
    optimizing route calculation based on expected arrival time.
  * api-change:``logs``: This release introduces the StartLiveTail API to tail
    ingested logs in near real time.
- From 1.31.12
  * api-change:``neptune``: This release adds a new parameter configuration
    setting to the Neptune cluster related APIs that can be leveraged to
    switch between the underlying supported storage modes.
  * api-change:``pinpoint``: This release includes Amazon Pinpoint API
    documentation updates pertaining to campaign message sending rate limits.
  * api-change:``securityhub``: Added new resource detail objects to ASFF,
    including resources for AwsDynamoDbTable, AwsEc2ClientVpnEndpoint,
    AwsMskCluster, AwsS3AccessPoint, AwsS3Bucket
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
* Mon Dec 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.31.11
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.31.11/CHANGELOG.rst
- Add patch to update docutils dependency (bsc#1217336)
  + ac_update-docutils.patch
- Update Requires in spec file from setup.py
* Fri Nov 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.30.6
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.30.6/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Oct  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.61
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.61/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.36
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.27/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Aug 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.27
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.27/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jul 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.2/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jun 29 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.163
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.163/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jun 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.153
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.153/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue May  9 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.130
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.130/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr 19 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.115
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.115/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1209255, jsc#PED-3780)
* Mon Mar 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.89
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.89/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.78
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.78/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.71
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.71/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.66
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.66/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.58
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.58/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.52
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.52/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.41
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.41/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.26
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.26/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.21
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.21/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.8
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.8/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Nov  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.2/CHANGELOG.rst
- Relax upper version constraint for python-colorama in
  BuildRequires and Requires to 0.5.0 (bsc#1204917)
- Update Requires in spec file from setup.py
* Thu Nov  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1204537, jsc#PED-2333)
* Tue Oct 25 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.26.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.26.0/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.91
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.91/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Oct  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.85
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.85/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Sep 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.76/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Sep 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.72
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.72/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Sep  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.64
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.64/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.55
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.55/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Aug  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.45
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.45/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jul 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.37
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.37/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jun 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.20
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.20/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jun  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.2/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.24.4 (bsc#1199716)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.4/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue May 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.24.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu May 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.23.11
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.11/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr 27 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.23.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Apr  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.87
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.87/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Mar  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.65
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.65/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Feb  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.46
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.46/CHANGELOG.rst
- Add missing python-rpm-macros to BuildRequires
- Update Requires in spec file from setup.py
* Fri Jan 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.35/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jan  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.28
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.28/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Dec 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.24
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.24/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Oct 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.21.6
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.21.6/CHANGELOG.rst
- Relax upper version dependency for python-docutils in Requires
- Update Requires in spec file from setup.py
* Fri Sep 10 2021 Michal Vyskocil <mvyskocil@opensuse.org>
- Update to version 1.20.32
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.32/CHANGELOG.rst
- Fix rpmlint warnings
  + use defattr for default permissions
  + mark zsh completion file as a config file
- Use github download url as a Source0
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.20.7
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.20.7 (bsc#1189649)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.112
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.112/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jun 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.86
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.86/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.75
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.75/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Apr 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.50
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.50/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Feb 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.9 (bsc#1182421, bsc#1182422, jsc#ECO-3352, jsc#PM-2485)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.9/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan 12 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.212
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.212/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.185
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.185/CHANGELOG.rst
- Rename README.md to README.rst in %%doc section
- Update Requires in spec file from setup.py
* Fri Oct  9 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.156
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.156/CHANGELOG.rst
- Drop patches no longer required
  + hide_py_pckgmgmt.patch
- Update Requires in spec file from setup.py
* Mon Sep  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.133
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.133/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Aug 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.117 (bsc#1175147, bsc#1175148, jsc#ECO-2362, jsc#PM-2069)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.117/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Rename README.rst to README.md in %%docs section
* Thu Jul 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.98
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Jun 15 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.79
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Apr  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.38 (bsc#1166924, bsc#1168943)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.38/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Apr  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add bash-completion to BuildRequires for suse_version <= 1315
* Fri Apr  3 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.35/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Mar 24 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.27
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.27/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Feb 17 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.0/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Install aws bash completetion script into system path
  + Install aws zsh completion script into /etc/zsh_completion.d
  + Update Requires in spec file from setup.py
* Fri Feb 14 2020 Dirk Mueller <dmueller@suse.com>
- make it possible to find the package under the name "awscli"
* Mon Feb 10 2020 Robert Schweikert <rjschwei@suse.com>
- Add bash command completion capability (boo#1117074)
* Thu Jan 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.17.9
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.17.9/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Dec  5 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.297
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.297/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Nov 14 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.281
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.281/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Oct 14 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.258
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.258/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Sep 27 2019 Robert Schweikert <rjschwei@suse.com>
- Add groff as a dependency (boo# 1152258)
* Thu Aug 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.223 (bsc#1146853)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.223/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Jun 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.189
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.189/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jun 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.182
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.182/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Jun 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.176
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.176/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version constraints for python-PyYAML and python-rsa
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Run recursive find with chmod to remove executable bit for
  REST files in example folder to fix rpmlint warning
* Wed Feb 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.103
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.103/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jan 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.94
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.94/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Jan  6 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.84
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.84/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Dec  4 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.61 (bsc#1118021, bsc#1118024)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.61/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version dependency on colorama to <= 0.4.1 (boo#1118099)
* Tue Nov  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.48
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.48/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Sep 13 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.1 (bsc#1105988, bsc#1092493)
  + Fix CVE-2018-15869
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.1/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Replace vendored version of six from botocore with upstream version
  + Update Requires in spec file from setup.py
* Mon Aug 13 2018 adrian.glaubitz@suse.com
- Update to version 1.15.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.76/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Aug 12 2018 rjschwei@suse.com
- Be less strict with the YAML version requirement
- Switch the license file to %%license
* Sun Jul 22 2018 adrian.glaubitz@suse.com
- Update to version 1.15.63
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.63/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Jun 19 2018 adrian.glaubitz@suse.com
- Update to version 1.15.40 (boo#1088310)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.40/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Nov 10 2017 jengelh@inai.de
- Do not have description assume any particular user.
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 1.11.185 (boo#1066528)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.185/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
* Tue Sep 12 2017 rjschwei@suse.com
- Update to version 1.11.151
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.151/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
- Remove build capability for SLE 11
- Set up for Python 3 build distro > SLE 12 openSUSE Leap 42.x
* Wed Jun 14 2017 rjschwei@suse.com
- Update to version 1.11.104 (bsc#1044370)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.104/CHANGELOG.rst
* Thu Dec 15 2016 rjschwei@suse.com
- Update to 1.11.29 (bsc#1015776)
  + forward port hide_py_pckgmgmt.patch
  + feature:batch: Update batch command to latest version
  + feature:logs: Update logs command to latest version
  + feature:rds: Update rds command to latest version
  + feature:dms: Update dms command to latest version
  + feature:marketplacecommerceanalytics: Update marketplacecommerceanalytics
    command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:sts: Update sts command to latest version
- From 1.11.28
  + feature:cloudfront: Add lambda function associations to cache behaviors.
  + feature:rds: Add cluster create data to DBCluster APIs.
  + bugfix:opsworks: This fixes an issue with opsworks register --local and
    python3 on some versions of linux.
  + feature:waf-regional: With this new feature, customers can use AWS WAF
    directly on Application Load Balancers in a VPC within available regions
    to protect their websites and web services from malicious attacks such
    as SQL injection, Cross Site Scripting, bad bots, etc.
- From 1.11.27
  + feature:config: Update config command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:s3: Update s3 command to latest version
- From 1.11.26
  + feature:sts: Update sts command to latest version
  + feature:config: Update config command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:pinpoint: Update pinpoint command to latest version
- From 1.11.25
  + bugfix:opsworks-cm: Rename opsworkscm to opsworks-cm, keeping support
    for opsworkscm.
- From 1.11.24
  + feature:pinpoint: Update pinpoint command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:alias: Add ability to alias commands in the CLI
  + feature:xray: Update xray command to latest version
  + feature:s3: Display transfer speed for s3 commands
  + feature:ssm: Update ssm command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:codebuild: Update codebuild command to latest version
  + feature:opsworkscm: Update opsworkscm command to latest version
  + feature:shield: Update shield command to latest version
  + feature:stepfunctions: Update stepfunctions command to latest version
  + feature:appstream: Update appstream command to latest version
  + feature:health: Update health command to latest version
  + feature:ec2: Update ec2 command to latest version
- From 1.11.23
  + feature:polly: Update polly command to latest version
  + feature:snowball: Update snowball command to latest version
  + feature:rekognition: Update rekognition command to latest version
  + feature:lightsail: Update lightsail command to latest version
  + feature:--generate-cli-skeleton output: Add support for generating
    sample output for command
- From 1.11.22
  + feature:s3: Update s3 command to latest version
- From 1.11.21
  + feature:s3: Update s3 command to latest version
  + feature:glacier: Update glacier command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:route53: Update route53 command to latest version
- From 1.11.20
  + feature:ecs: Update ecs command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.11.19
  + feature:cloudformation deploy: Add command to simplify deployments
    of cloudformation stack changes.
  + feature:emr: Update emr command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:elastictranscoder: Update elastictranscoder command to latest
    version
  + feature:cloudformation package: Add command to package source code for
    cloudfromation template.
  + feature:gamelift: Update gamelift command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.11.18
  + bugfix:Powershell: Properly set return code on Powershell.
  + feature:cloudwatch: Update cloudwatch command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:meteringmarketplace: Update meteringmarketplace command to
    latest version
- From 1.11.17
  + feature:route53: Update route53 command to latest version
  + feature:servicecatalog: Update servicecatalog command to latest version
- From 1.11.16
  + feature:kinesis: Update kinesis command to latest version
  + feature:ds: Update ds command to latest version
  + feature:elasticache: Update elasticache command to latest version
- From 1.11.15
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.14
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:logs: Update logs command to latest version
- From 1.11.13
  + feature:directconnect: Update directconnect command to latest version
- From 1.11.12
  + feature:ses: Update ses command to latest version
- From 1.11.11
  + bugfix:cloudtrail: Use STS instead of IAM in CreateSubscription
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.11.10
  + feature:autoscaling: Update autoscaling command to latest version
  + feature:elbv2: Update elbv2 command to latest version
- From 1.11.9
  + feature:ecs: Update ecs command to latest version
  + feature:sms: Update sms command to latest version
- From 1.11.8
  + feature:waf: Update waf command to latest version
  + feature:s3: Port mv to s3transfer.
  + feature:budgets: Update budgets command to latest version
- From 1.11.7
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:iot: Update iot command to latest version
  + feature:config: Update config command to latest version
  + feature:kinesisanalytics: Update kinesisanalytics command to latest version
  + feature:rds: Update rds command to latest version
- From 1.11.6
  + feature:route53: Update route53 command to latest version
  + feature:--region: Add support for us-east-2
- From 1.11.5
  + bugfix:s3 sync --delete: Fix regression where --delete would not delete
    local files
- From 1.11.4
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:s3: Integrate sync command with s3transfer
  + feature:acm: Update acm command to latest version
  + feature:s3: Output progress even when discovering new files to transfer
- From 1.11.3
  + bugfix:Pagination: Fix validation error when providing --no-paginate
    with normalized paging argument.
  + feature:apigateway: Update apigateway command to latest version
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:rds: Update rds command to latest version
  + feature:codedeploy: Update codedeploy command to latest version
  + feature:sns: Update sns command to latest version
  + feature:kms: Update kms command to latest version
  + feature:elasticache: Update elasticache command to latest version
  + feature:ecr: Update ecr command to latest version
- From 1.11.2
  + feature:s3: Update s3 command to latest version
  + feature:waf: Update waf command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:kms: Update kms command to latest version
  + feature:opsworks: Update opsworks command to latest version
  + bugfix:s3: Refactor rb into its own command. In addition, validate that
    no key is supplied regardless of whether or not the force argument is
    supplied.
  + bugfix:route53domains: Rename --end to --end-time to fix a bug relating
    to argparse prefix expansion. Alias --start to --start-time to maintain
    a consistent interface while keeping the old parameter.
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.1
  + bugfix:s3: Fix regression when downloading empty files.
- From 1.11.0
  + feature:snowball: Update snowball command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:s3: Port cp and rm to s3transfer. Improve progress for those
    commands, showing byte progress.
- Upstream version jump from 1.10.67 to 1.11.0
* Thu Nov 17 2016 dmueller@suse.com
- update to 1.10.67
  * more than 500 changes, have a look at
  https://github.com/aws/aws-cli/compare/1.10.38...1.10.67
* Tue Jun 21 2016 rjschwei@suse.com
- Update to version 1.10.38 (bsc#985858)
  + forward port hide_py_pckgmgmt.patch
  + feature:acm: Update acm command to latest version
  + feature:ses: Update ses command to latest version
  + feature:rds: Update rds command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.37
  + feature:s3: Update s3 command to latest version
- From 1.10.36
  + feature:dynamodbstreams: Update dynamodbstreams command to latest version
  + feature:machinelearning: Update machinelearning command to latest version
  + feature:iot: Update iot command to latest version
  + bugfix:Pagination: Fix regression with --no-paginate introduced in
    [#1958] (fixes #1993)
- From 1.10.35
  + feature:ec2: Update ec2 command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.10.34
  + feature:elasticache: Update elasticache command to latest version
- From 1.10.33
  + feature:rds: Update rds command to latest version
  + feature:ec2: Update ec2 command to latest version
  + bugfix:help: Write help content to stdout if less is not installed.
    Fixes #1957
- From 1.10.32
  + feature:firehose: Update firehose command to latest version
  + bugfix:Table: Fix rendering of tables with double-width characters.
  + feature:ec2: Update ec2 command to latest version
  + feature:ecs: Update ecs command to latest version
- From 1.10.31
  + feature:application-autoscaling: Adds support for Application Auto Scaling.
    Application Auto Scaling is a general purpose Auto Scaling service for
    supported elastic AWS resources. With Application Auto Scaling, you can
    automatically scale your AWS resources, with an experience similar to
    that of Auto Scaling.
- From 1.10.29
  + feature:dynamodb: Update dynamodb command to latest version
  + bugfix:Shorthand: Remove back-compat shorthand features from new services.
  + bugfix:Paginator: Print a better error when pagination params are
    supplied along with no-paginate.
  + bugfix:ec2: Sets MaxResults to default value of 1000.
  + feature:workspaces: Update workspaces command to latest version
  + feature:discovery: Update discovery command to latest version
- From 1.10.28
  + feature:ec2: Update ec2 command to latest version
  + feature:ssm: Update ssm command to latest version
  + feature:discovery: Update discovery command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.10.27
  + feature:storagegateway: Update storagegateway command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:emr: Update emr command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:iam: Update iam command to latest version
- From 1.10.26
  + feature:kms: Update kms command to latest version
  + feature:sts: Update sts command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:ecs: Update ecs command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.25
  + feature:inspector: Update inspector command to latest version
  + feature:codepipeline: Update codepipeline command to latest version
  + bugfix:Configure: Fix issue causing prompts not to display on mintty.
    Fixes #1925
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
- From 1.10.24
  + feature:route53domains: Update route53domains command to latest version
  + feature:opsworks: Update opsworks command to latest version
- From 1.10.23
  + feature:ecr: Update ecr command to latest version
  + feature:acm: Update acm command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:sts: Update sts command to latest version
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.10.22
  + feature:emr: Add support for smart targeted resize feature
  + feature:iot: Add SQL RulesEngine version support
  + feature:acm: Add tagging support for ACM
- From 1.10.21
  + feature:aws ec2: Add support for two new EBS volume types
  + feature:aws cognito-idp: Add support for new service, aws cognito-idp
  + feature:aws kinesis: Update aws kinesis command to latest version
  + feature:aws elasticbeanstalk: Add support for automatic platform
    version upgrades with managed updates
  + feature:aws devicefarm: Update aws devicefarm command to latest version
  + feature:aws s3: Add support for Amazon S3 Transfer Acceleration
  + feature:aws firehose: Update firehose command to latest version
- From 1.10.20
  + feature:iot: Add commands for managing CA certificates.
  + bugfix:ec2 wait: Fix issues with waiting on incorrect error code.
  + bugfix:s3: Fix issue where multipart uploads were not being properly
    aborted after Cntrl-C. (issue 1905)
* Mon Apr 11 2016 rjschwei@suse.com
- Update to version 1.10.19 (bsc#974993)
  + forward port hide_py_pckgmgmt.patch
  + feature:lambda: Added support for setting the function runtime as
    nodejs4.3, as well as updating function configuration to set the runtime.
  + feature:ds: Added support for Directory Service Conditional Forwarder APIs.
  + feature:elasticbeanstalk: Adds support for three additional elements in
    AWS Elasticbeanstalk's DescribeInstancesHealthResponse: Deployment,
    AvailabilityZone, and InstanceType. Additionally adds support for
    increased EnvironmentName length from 23 to 40.
  + bugfix:Paginator: Allow non-specified input tokens in old starting token
    format.
- From 1.10.18
  + feature:apigateway: Added support for API Import
  + feature:route53: Added support for metric-based health checks and
    regional health checks.
  + feature:sts: Added support for GetCallerIdentity, which returns details
    about the credentials used to make the API call. The details include name
    and account, as well as the type of entity making the call, such as an
    IAM user vs. federated user.
  + feature:s3api: Added support for VersionId in PutObjectAcl (issue 856)
  + bugfix:s3api: Add validation to enforce S3 metadata only contains ASCII.
    (issue 861)
  + bugfix:Exceptions: Consistently parse errors with no body (issue 859)
  + bugfix:Config: Handle case where S3 config key is not a dict (issue 858)
- From 1.10.17
  + feature:acm: Update command to latest version
  + feature:cloudformation: Update command to latest version
  + feature:codedeploy: Update command to latest version
  + feature:dms: Update command to latest version
  + feature:elasticache: Update command to latest version
  + feature:elasticbeanstalk: Update command to latest version
  + feature:redshift: Update command to latest version
  + feature:waf: Update command to latest version
  + bugfix:Pagintor: Fix regression when providing a starting token for a
    paginated command (botocore issue 849)
  + bugfix:Response Parsing: Handle case when generic HTML error response
    is received (botocore issue 850)
  + bugfix:Request serialization: Handle case when non str values are
    provided for header values when using signature version 4
    (botocore issue 852)
  + bugfix:Retry: Retry HTTP responses with status code 502
    (botocore issue 853)
  + bugfix:ec2 run-instances: Fix issue when providing
  - -secondary-private-ip-address-count argument (issue 1874)
- From 1.10.16
  + feature:elasticache: Update command to latest version
  + feature:rds: Update command to latest version
  + feature:storagegateway: Update command to latest version
- from 1.10.15
  + feature:aws devicefarm: Add support to pay a flat monthly fee for
    unlimited testing of your Android and iOS apps with AWS Device Farm
    device slots
  + feature:aws rds: Add support for customizing the order in which Aurora
    Replicas are promoted to primary instance during a failover
- From 1.10.14
  + feature:meteringmarketplace: The AWS Marketplace Metering Service
    enables sellers to price their products along new pricing dimensions.
    After a integrating their product with the AWS Marketplace Metering
    Service, that product will emit an hourly record capturing the usage of
    any single pricing dimension. Buyers can easily subscribe to software
    priced by this new dimension on the AWS Marketplace website and only
    pay for what they use.
  + feature:s3api: Added support for delete marker and abort multipart
    upload lifecycle configuration.
  + feature:iot: Added support for Amazon Elasticsearch Service and
    Amazon Cloudwatch actions for the AWS IoT rules engine.
  + feature:cloudhsm: Added support for tagging resources.
- From 1.10.13
  + feature:DMS: Added support for AWS Database Migration Service
  + feature:SES: Added support for white-labeling
  + feature:CodeDeploy: Added support for BatchGetDeploymentGroups
  + feature:endpoints: Updated endpoints to latest version
  + bugfix:groff: Fix groff command which was causing issues on some systems
  + bugfix:shorthand: Allow # in keys in the shorthand parser
- From 1.10.12
  + feature:gamelift: Update command to latest version
  + feature:iam: Update command to latest version
  + feature:redshift: Update command to latest version
- From 1.10.11
  + feature:acm: Update acm command to latest version
  + feature:codecommit: Update codecommit model to latest version
  + feature:config: Update config command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:events: Update events command to latest version
  + bugfix:aws s3 cp: Add error checking when attempting recursive copies
    or syncs with streaming output (issue 1771)
- From 1.10.10
  + feature:aws ec2: Add support for VPC peering with security groups.
  + feature:aws ds: Add support for SNS event notifications.
  + bugfix:aws s3 rb: Fix issue where bucket is still attempted to be
    removed when the preceding delete requests failed. (issue 1827)
  + bugfix:aws storagegateway: Fix issue in aliasing required args.
    (issue 1790)
- From 1.10.9
  + bugfix:aws s3: Avoid MD5 checksumming if unavailable. (issue 1812)
  + feature:aws dynamodb: Add support for describing limits.
  + feature:aws apigateway: Add support for testing invoke authorizers
    and flushing stage authorizers cache.
  + feature:aws cloudsearchdomain: Add support for new stat fields.
- From 1.10.8
  + bugfix:aws s3: Disable use of MD5 when SHA256 checksum is already
    calculated for the body (botocore issue 804)
  + bugfix:FIPS: Handle case where MD5 cipher is not available on FIPS
    compliant systems (botocore issue 807)
  + feature:aws cloudformation: Update AWS CloudFormation command to the
    latest version
  + feature:aws logs: Update Amazon CloudWatch Logs command to the latest
    version
  + feature:aws ses: Update Amazon SES to the latest version
  + feature:aws autoscaling: Update Auto Scaling to the latest version
- From 1.10.7
  + bug:aws configure set: Fix issue when adding entries to an empty
    profile section (issue 1806)
  + feature:aws route53: Add suport for SNI health checks
- From 1.10.6
  + feature:aws storagegateway: Added support for user-supplied barcodes.
  + feature:aws codedeploy: Added support for setting up triggers for a
    deployment group.
  + bugfix:aws emr: Fix missing dns name issue with private clusters.
    (issue 1749)
  + bugfix:aws emr: Fix issue where impala args were not joined with commas.
    (issue 1802)
- From 1.10.5
  + feature:aws rds: Added support for Cross-account Encrypted (KMS) snapshot
    sharing.
  + feature:aws emr: Added support for adding EBS storage to EMR instances.
  + bugfix:pagination: Fixed a bug that was causing non-string service
    tokens to fail on serialization
- From 1.10.4
  + feature:aws lambda: Add support for accessing resources in your VPC.
  + feature:aws apigateway: Add support for custom request authorizers.
- From 1.10.3
  + feature:aws cloudfront: Add support for new ACMCertificateARN parameter
  + feature:aws marketplacecommerceanalytics generate-data-set: Add support
    for --customer-defined-values parameter
- From 1.10.2
  + feature:aws gamelift: Add support for AWS GameLift
  + bugfix:Assume Role: Fix issue where temporary credentials from assuming
    a role were not being properly cached (issue 1684)
- From 1.10.1
  + feature:aws waf: Add support for blocking, allowing, or monitoring
    (count) requests based on the content in HTTP request bodies.
  + bugfix:aws ssm: Remove constraint on Amazon EC2 instance id's.
    (issue 1729)
- From 1.10.0
  + feature:aws acm: adds support for AWS Certificate Manager
  + feature:aws cloudfront: adds support for AWS Certificate Manager
    certificates
  + feature:aws cloudfront create-distribution: Adds support for
  - -origin-domain-name and --default-root-object
  + feature:aws cloudfront update-distribution: Adds support for
  - -default-root-object
  + feature:aws iot: adds support for topic rules
  + feature:aws cloudformation: adds suport for ContinueUpdateRollback
- From 1.9.21
  + feature:aws sts: now returns RegionDisabledException instead of
    AccessDenied when a user sends an API request to an STS regional
    endpoint that is not activated for that AWS account. This enables
    customers to more easily decide how to respond, such as by trying to
    call a different region instead of simply failing the call.
  + feature:aws opsworks: adds support for new enums.
  + feature:aws devicefarm: adds support running Appium tests written in
    Python against your native, hybrid and browser-based apps on AWS Device
    Farm.
- From 1.9.20
  + bugfix:aws cloudfront: Fix regression in waiters.
- From 1.9.19
  + feature:aws events: Initial support for Amazon CloudWatch Events.
    CloudWatch Events allows you to track changes to your AWS resources
    with less overhead and greater efficiency.
  + feature:aws ec2: Adds support for purchasing reserved capacity for
    specific blocks of time on a one-time of recurring basis.
  + feature:aws cloudfront: Adds support for HTTPS-only connections, and
    control of edge-to-origin request headers.
  + bugfix:aws s3: Gracefully handle encoding errors when printing S3
    keys (issue 1719)
- From 1.9.18
  + feature:aws ec2: Enables support for DNS resolution of public hostnames
    to private IP addresses when queried over ClassicLink. Additionally, you
    can now access private hosted zones associated with your VPC from a
    linked EC2-Classic instance. ClassicLink DNS support makes it easier
    for EC2-Classic instances to communicate with VPC resources using public
    DNS hostnames.
  + feature:aws ec2: Add support for the new 63-bit EC2 Instance and
    Reservation IDs.
- From 1.9.17
  + bugfix:aws ssm: Documentation update.
- From 1.9.16
  + feature:aws ec2: Add new EC2 instance type: t2.nano
  + feature:aws datapipeline list-runs: Add support for output format
- From 1.9.15
  + feature:aws ecr: Add aws ecr commands
  + feature:aws emr: Update aws emr create-cluster to accept Amazon EC2
    security group
  + feature:aws ecs: Update ecs command to include a new deployment option
- From 1.9.14
  + feature:aws rds: Adds Enhanced Monitoring support so that you can
    monitor operating system metrics for your RDS DB instances
  + feature:aws configservice: Support for IAM resource types
  + feature:aws cloudtrail: Adds isMultiRegion to some of the commands
  + feature:aws cloudfront: Adds support for gzip
  + feature:aws ec2: Adds new commands for VPC Managed NAT
- From 1.9.13
  + feature:aws ec2 copy-image: Adds two optional parameters to support
    launching EC2 instances with EBS encrypted boot volumes.
  + bugfix:aws: Fix regression when using AWS_DATA_PATH environment
    variable (issue 736)
* Thu Dec 10 2015 rjschwei@suse.com
- Update to version 1.9.12 (bsc#958686)
  + feature:aws configure add-model: Added command for updating commands
    in the CLI and clients in boto3. (issue 1664)
  + feature:aws cloudfront create-invalidation: Add a new --paths option.
    (issue 1662)
  + feature:aws cloudfront sign: Add a new command to create a signed url.
    (issue 1668)
  + feature:aws autoscaling: Added support for protecting instances from
    scale-in events.
  + feature:aws rds: Added support for Aurora encryption at rest.
- From version 1.9.11
  + feature:aws rds: Added support for specifying port number.
  + feature:aws ds: Added support for Microsoft ActiveDirctory.
  + feature:aws route53: Added support for TrafficFlow, a new management
    and modeling layer for Route53.
  + feature:Timeouts: Added additonal options for configuring socket timeouts.
- From version 1.9.10
  + feature:aws config: Added support for dedicated hosts.
  + feature:aws s3: Added support for custom metadata in cp, mv, and sync.
- From version 1.9.9
  + feature:aws s3api: Added support for the aws-exec-read canned ACL on
    objects.
  + feature:aws elasticbeanstalk: Added support for composable web applications.
  + feature:aws ec2: Added support for EC2 dedicated hosts.
  + feature:aws ecs: Added support for task stopped reasons and task start
    and stop times.
- From version 1.9.8
  + feature:Read Timeouts: Add --cli-read-timeout to specify the number of
    seconds until a read times out.
  + bugfix:aws s3: Fix regression when downloading a restored Glacier object
    (issue 1650 <https://github.com/aws/aws-cli/pull/1650>__)
  + bugfix:aws s3: Fix issue when encountering "out of disk space" errors as
    well as permissions errors when downloading large files (issue 1645,
    issue 1442)
  + bugfix:aws opsworks register: Support --no-verify-ssl argument for the
    aws opsworks register command (issue 1632)
  + feature:s3: Add support for Server-Side Encryption with KMS and
    Server-Side Encryption with Customer-Provided Keys. (issue 1623)
- From version 1.9.7
  + feature:aws rds: Cross account snapshot sharing and Modify DB Instance
    Visibility features
  + bugfix:memory management: Resolve a potential memory leak when creating
    lots of clients on Python 2.6 and Linux 2.6
  + bugfix:presign url: Now generate_presigned_url() works correctly with
    different expiry time
- From version 1.9.6
  + bugfix:shorthand: Allow . as a valid key character. (issue 1628)
  + feature:aws apigateway: Support for stage variables to configure
    the different deployment stages
- From version 1.9.5
  + bugfix:aws help: Gracefully handle Ctrl-C interrupts. (issue 1619)
  + bugfix:aws datapipeline create-default-roles: Fix issue with error
    handling. (issue 1618)
  + bugfix:aws s3: Skip glacier objects when downloading from S3. (issue 1581)
  + feature:aws s3api: Auto-populate --copy-source-sse-customer-key-md5
    (botocore issue 709)
- From version 1.9.4
  + feature:aws datapipeline create-default-roles: Creates default IAM
    roles for creating EMR clusters. (issue 1616)
  + feature:aws devicefarm: Add commands for updating and deleting projects,
    device pools, uploads, and runs.
- From version 1.9.3
  + feature:aws iam: Add support for resource-level policy simulation
- From version 1.9.2
  + bugfix:aws s3: Fix some local path validation issues (issue 1575)
  + bugfix:aws storagegateway: Fix --tape-ar-ns, --volume-ar-ns, and
  - -vtl-device-ar-ns to --tape-arns, --volume-arns, and --vtl-device-arns,
    respectively. The old arguments are still supported for backwards
    compatibility, but are no longer documented. (issue 1599)
  + bugfix:aws configservice subscribe: Fix an issue when creating a new
    S3 bucket (issue 1593)
  + bugfix:aws apigateway put-integration: Fix issue with --uri and
  - -integration-http-method parameters (issue 1605)
- From version 1.9.1
  + feature:aws ssm: Add support for Amazon EC2 Run Command
  + feature:aws apigateway: Add support for Amazon API Gateway
- From version 1.9.0
  + feature:aws iam: Add policy simulator support
  + feature:aws autoscaling: Add support for launch configurations
    that include encrypted Amazon Elastic Block Store (EBS) volumes
  + feature:configure: Add support for ca_bundle config variable
  + feature:Assume Role: Add role_session_name config variable to control
    the RoleSessionName when assuming roles (issue 1389)
  + bug:Argument Parsing: Handle case when empty list parameter was
    specified with no value (issue 838)
- From version 1.8.13
  + feature:aws deploy: Compress zip files when using aws deploy push
    (issue 1534 <https://github.com/aws/aws-cli/pull/1534>--)
  + bugfix:Shorthand Parser: Fix issue when display error message for
    multiline shorthand syntax values (issue 1543)
  + bugfix:aws route53: Automatically retry Throttling and
    PriorRequestNotComplete errors (botocore issue 682)
  + feature:aws s3/s3api: Add support for changing the bucket addressing
    style (botocore issue 673)
  + bugfix:aws s3api: Add missing --server-side-encryption option to
    upload-part command
  + feature:aws kms: Add ability to delete customer master keys (CMKs)
* Sat Oct 10 2015 rjschwei@suse.com
- Update to version 1.8.12 (bsc#949877)
  + feature:aws iot: Add support for AWS IoT
  + feature:aws iot-data: Add support for AWS IoT Data Plane
  + feature:aws lambda: Add support for aliasing and function versioning
  + feature:aws ecs: Update commands
  + feature:aws marketplacecommerceanalytics: Add support for AWS
    Marketplace Commerce Analytics
  + feature:aws firehose: Add support for Amazon Kinesis Firehose
  + feature:aws inspector: Add support for Amazon Inspector
  + feature:aws kinesis: Add support for updating stream retention periods
  + feature:aws configservice: Add support for config rules
  + feature:aws waf: Add support for AWS WAF
  + feature:aws ec2: Add support for spot blocks
  + feature:aws cloudfront: Add support for adding Web ACLs to CloudFront
    distributions
  + feature:aws es: Adds support for the new Amazon Elasticsearch
  + feature:aws cloudtrail: Adds support for log file integrity validation,
    log encryption with AWS KMS-Managed Keys (SSE-KMS), and trail tagging.
  + feature:aws rds create-db-instance: --db-instance-class has a new value
    as db.t2.large
  + feature:aws workspaces: Adds support for volume encryption in Amazon
    WorkSpaces.
  + feature:aws ses: Adds 17 new operations for accepting incoming emails.
  + feature:aws cloudformation describe-account-limits: This is a new API.
  + feature:aws ec2 modify-spot-fleet-request: This is a new API.
  + bugfix:aws elasticbeanstalk: Documentation update.
  + feature:aws cognito-sync: Update API to latest version
  + feature:aws cognito-identity: Update API to latest version
  + bugfix:Assume Role Provider: Fix issue where profile does not exist
    errors were not being propogated back to the user (issue 1515)
  + bugfix:Shorthand Syntax: Fix parser regression when a key name has an
    underscore character (issue 1510)
  + feature:aws s3: Add support for STANDARD_IA storage class to the aws s3
    commands (issue 1511)
  + feature:aws logs: Add support for create-export-task, cancel-export-task,
    and describe-export-tasks.
  + bugfix:Output: Only omit printing response to stdout if the response is
    an empty dictionary (issue 1496)
  + feature:aws s3/s3api: Update Amazon S3 commands to the latest version
  + feature:aws ec2 request-spot-fleet: Add new Diversified bidding strategy
    parameter
  + feature:aws ec2 describe-snapshots: Add new dataEncryptionKeyId and
    StateMessage parameters
  + feature:aws efs describe-mount-targets: Add new optional MountTargetId
    parameter
  + feature:aws route53: Add calculated health checks and latency health checks
  + bugfix:StreamingBody: File-like object for HTTP response can now be
    properly closed
  + feature:aws iam: Add two new APIs that enable programmatic access to
    the IAM policy simulator
  + feature:aws importexport: Documentation update
  + bugfix:aws machinelearning: Remove a constraint
  + feature:aws kinesis get-records: Add a timestamp field to all Records
  + bugfix:aws cloudfront: Add paginators and waiters
  + feature:aws storagegateway: Add support for resource tagging.
  + feature:aws ec2 request-spot-fleet: Add support for new request config
    parameters
  + bugfix:Shorthand Parser: Fix regression where '-' character was not
    accepted as a key name in a shorthand value (issue 1470)
  + bugfix:Shorthand Parser: Fix regression where spaces in unquoted
    values were not being accepted (issue 1471)
  + feature:aws configservice: Add support for listing discovered resources
  + bugfix:aws emr create-default-roles: Fix the issue where the command
    would fail to honor an existing AWS_CA_BUNDLE environment setting and
    end up with "SSLError: object has no attribute" (issue 1468)
  + feature:Shorthand Syntax: Add support for nested hashes when using
    shorthand syntax (issue 1444)
  + feature:aws codepipeline: Add support for specification of an encryption
    key to use with the artifact bucket, when creating and updating a pipeline
  + feature:aws s3: Add support for event notification filters
  + bugfix:aws iam create-virtual-mfa-device: Fix issue when an error
    response is received from the create-virtual-mfa-device command (issue 1447)
  + feature:aws elasticbeanstalk: Add support for enhanced health reporting
    in aws elasticbeanstalk commands
  + feature:Shared Credentials File: Add support for changing the shared
    credentials file from the default location of ~/.aws/credentials
    by setting the AWS_SHARED_CREDENTIALS_FILE environment variable
    (botocore issue 623)
  + feature:Waiters: Add aws iam wait instance-profile-exists and aws
    iam wait user-exists commands (botocore issue)
  + feature:aws swf: Add support for Added support for invoking AWS
    Lambda tasks from an Amazon SWF workflow.
  + feature:aws devicefarm: Add support for testing iOS applications
    with AWS Device Farm.
* Fri Jul 31 2015 ms@suse.com
- update to version 1.7.42 (fate#318337)
  - feature:``aws opsworks``: Add support for managing Amazon ECS
  - feature:``aws rds``: Add support for Amazon Aurora
  - feature:``aws s3api``: Add support for more types of event notifications.
  - feature:``aws s3api``: Add support for GET/HEAD storage class response
  - feature:``aws logs``: Add destination API support.
  - feature:``aws glacier``: Add support for Vault Lock.
  - feature:``aws emr``: Add support for release-based clusters.
  - feature:``aws ecs``: Update API
* Mon Jun  1 2015 rjschwei@suse.com
- update to version 1.7.31 (bnc#905354)
  - Follow up to previous update to address API compatibility issues
    with botocore
  - Improved lambda support
  - Add support for uploading code using Amazon S3
  - Preview services are now documented
    and will also show up in the list of available services
  + From 1.7.30
  - Add support for ``aws efs``
  - Add paginators and waiters for ``aws ecs``
* Tue May 26 2015 rjschwei@suse.com
- update to version 1.7.29 (bnc#905354)
  + Follow up to previous update to address compatibility with latest
    amazon-ecs-agent
  + From 1.7.28
  - feature:aws ec2: Add support for Spot Fleet.
  - feature:aws opsworks: Add support for custom AutoScaling.
  - feature:aws elasticbeanstalk: Update model to latest version.
  + From 1.7.27
  - feature:aws ds: Add support for AWS Directory Service.
  - feature:aws ec2: Add support for VPC endpoints for Amazon S3.
  - feature:aws ec2: Add support for EIP Migration.
  - feature:aws logs: Add support for filtering log events.
  + From 1.7.26
  - feature:aws glacier: Add support for vault policies.
  - bugfix:aws iam create-open-id-connect-provider: Fix issue where the
  - -url parameter would try to retrieve the contents from the url instead
    of use the url as its value. (issue 1317)
  - bugfix:aws workspaces: Fix issue where throttling errors were not
    being retried (botocore issue 529)
  + From 1.7.25
  - feature:aws dynamodb query: Add support for KeyConditonExpression.
  + From 1.7.24
  - feature:aws help topics: Add support for listing available help topics.
  - feature:aws help config-vars: Add help topic for configuration variables.
  - feature:aws help return-codes: Add help topic for return codes.
  - feature:aws help s3-config: Add help topic for configuration of s3
    commands.
  - bugfix:aws lambda create-function/update-function-code: Improve
    error message when invalid --zip-file values are provided (issue 1296)
  - feature:aws ec2: Add support for new VM Import APIs, including
    import-image. The new APIs provide support for importing multi-volume
    VMs to Amazon EC2 and other enhancements.
  - feature:aws iam: Update AWS IAM command to latest version
  + From 1.7.23
  - feature:aws cognito-sync: Add support for Amazon Cognito Events.
  - bugfix:Parsing: Treat empty XML nodes in a response as an empty
    string instead of None if the underlying structure member is a string.
    This fixes the broken password-data-available Amazon EC2 waiter. Note:
    this changes the output of the CLI and may affect filtering with the
  - -query parameter. (issue 1252, botocore issue 506)
  + From 1.7.22
  - bugfix:aws ecs: Minor documentation fixes.
  + From 1.7.21
  - feature:aws workspaces: Add support for Amazon WorkSpaces.
  - feature:aws machinelearning: Add support for Amazon Machine Learning.
  - feature:aws s3api: Add support for specifying Lambda bucket
    notifications without needing to specify an invocation role.
  - feature:aws lambda: Update to latest api.
  - feature:aws ecs: Add support for Amazon ECS Service scheduler.
  + From 1.7.20
  - feature:aws datapipeline: Add support for deactivating pipelines.
  - feature:aws elasticbeanstalk: Add support for cancelling in-progress
    environment updates or application version deployment.
  + From 1.7.19
  - feature:aws codedeploy: Add register, deregister, install, and
    uninstall commands and update to the latest AWS CodeDeploy API.
  - feature:aws rds: Add support for describe-certificates.
  - feature:aws elastictranscoder: Add support for PlayReady DRM.
  - feature:aws ec2: Add support for D2 instances.
  + From 1.7.18
  - bugfix:Pagination: Fix issue where disabling pagination did not work
    when shadowing arguments. Affects commands such as aws route53
    list-resource-record-sets.
  - feature:aws elastictranscoder: Add support for job timing and
    input/output metadata
  - feature:aws iam: Add NamedPolicy to GetAccountAuthorization details
  - feature:aws opsworks: Allow for BlockDeviceMapping on EC2 instances
    launched through OpsWorks
  + From 1.7.17
  - feature:aws emr: Adds support for Amazon S3 client-side encryption
    in Amazon EMR and setting configuration values for several variables
    in the create-cluster and ssh commands. Also, the create-default-roles
    command will now auto-populate the Service Role and Instance Profile
    variables in the configuration file with the default roles after they
    are created.
  + From 1.7.16
  - feature:aws ec2 wait image-available: Add support for polling until
    an EC2 image is available (issue 1105)
  - feature:aws ec2 wait: Add support for additional EC2 waiters including
    instance-status-ok, password-data-available,
    spot-instance-request-fulfilled, and system-status-ok
  - feature:aws s3api: Add support for Amazon S3 cross region replication
  - feature:aws s3api: Add support for Amazon S3 requester pays (issue 797)
  - bugfix:Tab Completion: Fix issue where tab completion could not handle
    an LC_CTYPE of UTF-8 (issue 1233)
  - bugfix:aws s3api put-bucket-notification: Fix issue where an empty
    notification configuration could not be specified (botocore issue 495)
  - bugfix:aws cloudfront: Fix issue when calling cloudfront commands
    (issue 1234)
  - bugfix:aws ec2 copy-snapshot: Fix issue with the aws ec2 copy-snapshot
    command not correctly generating the presigned url argument
    (botocore issue 498)
  + From 1.7.15
  - feature:aws elastictranscoder: Add support for Applied Color
    SpaceConversion.
  - bugfix:aws --profile: Fix issue where explicitly specifying profile
    did not override credential environment variables. (botocore issue 486)
  - bugfix:aws datapipeline list-runs: Fix issue with --schedule-interval
    parameter. (issue 1225)
  - bugfix:aws configservice subscribe: Fix issue where users could not
    subscribe to a s3 bucket that they had no HeadBucket permissions to.
    (issue 1223)
  - bugfix:aws cloudtrail create-subscription: Fix issue where command
    would try to fetch the contents at a url using the contents of the
    custom policy as the url. (issue 1216)
  + From 1.7.14
  - feature:aws logs: Update aws logs command to the latest model.
  - feature:aws ec2: Add paginators for the describe-snapshots sub-command.
  - feature:aws cloudtrail: Add support for the new lookup-events
    sub-command.
  - bugfix:aws configure set: Fix issue when setting nested configuration
    values
  - feature:aws s3: Add support for --metadata-directive that allows
    metadata to be copied or replaced for single part copies. (issue 1188)
  + From 1.7.13
  - feature:aws cloudsearch: Update aws cloudsearch command to the latest
    model
  - feature:aws cognito-sync: Update aws cognito-sync command to allow
    customers to receive near-realtime updates as their data changes as
    well as exporting historical data. Customers configure an Amazon
    Kinesis stream to receive the data which can then be processed and
    exported to other data stores such as Amazon Redshift.
  - bugfix:aws opsworks: Fix issue with platform detection on linux
    systems with python3.3 and higher (issue 1199)
  - feature:Help Paging: Support paging through more when running help
    commands on windows (issue 1195)
  - bugfix:aws s3: Fix issue where read timeouts were not retried.
    (issue 1191)
  - feature:aws cloudtrail: Add support for regionalized policy templates
    for the create-subscription and update-subscription commands.
    (issue 1167)
  - bugfix:parsing: Fix issue where if there is a square bracket inside
    one of the values of a list, the end character would get removed.
    (issue 1183)
  + From 1.7.12
  - feature:aws datapipeline: Add support for tagging.
  - feature:aws route53: Add support for listing hosted zones by name
    and getting the hosted zone count.
  - bugfix:aws s3 sync: Remove --recursive parameter. The sync command is
    always a recursive operation meaning the inclusion or exclusion of
  - -recursive had no effect on the sync command. (issue 1171)
  - bugfix:aws s3: Fix issue where --endpoint-url was being ignored
    (issue 1142)
  + From 1.7.11
  - bugfix:aws sts: Allow calling assume-role-with-saml without credentials.
  - bugfix:aws sts: Allow users to make regionalized STS calls by
    specifying the STS endpoint with --endpoint-url and the region with
  - -region. (botocore issue 464)
  + From 1.7.10
  - bugfix:aws sts: Fix regression where if a region was not activated
    for STS it would raise an error if call was made to that region.
  + From 1.7.9
  - feature:aws cloudfront: Update to latest API
  - feature:aws sts: Add support for STS regionalized calls
  - feature:aws ssm: Add support for Amazon Simple Systems Management
    Service (SSM)
  + From 1.7.8
  - bugfix:aws s3: Fix auth errors when uploading large files to the
    eu-central-1 and cn-north-1 regions (botocore issue 462)
  + From 1.7.7
  - bugfix:aws ec2 revoke-security-group-ingress: Fix parsing of a
  - -port value of ICMP echo request (issue 1075)
  - feature:aws iam: Add support for managed policies
  - feature:aws elasticache: Add support for tagging
  - feature:aws route53domains: Add support for tagging of domains
  + From 1.7.6
  - feature:aws dynamodb: Add support for index scan
  - bugfix:aws s3: Fix issue where literal value for --website-redirect
    was not being used. (issue 1137)
  - bugfix:aws sqs purge-queue: Fix issue with the processing of the
  - -queue-url parameter (issue 1126)
  - feature:aws s3: Add support for config variable for changing S3 runtime
    values (issue 1122)
  - bugfix:Proxies: Fix issue with SSL certificate validation when using
    proxies and python 2.7.9 (botocore issue 451)
  + From 1.7.5
  - bugfix:aws datapipeline list-runs: Fix issue where --status values
    where not being serialized correctly (issue 1110)
  - bugfix:Output Formatting: Handle broken pipe errors when piping the
    output to another program (issue 1113)
  - bugfix:HTTP Proxy: Fix issue where aws s3/s3api commands would hang
    when using an HTTP proxy (issue 1116)
  - feature:aws elasticache wait: Add waiters for the aws elasticache
    wait (botocore issue 443)
  - bugfix:Locale Settings: Fix issue when Mac OS X has an LC_CTYPE value
    of UTF-8 (issue 945)
  + From 1.7.4
  - feature:aws dynamodb: Add support for online indexing.
  - feature:aws importexport get-shipping-label: Add support for
    get-shipping-label.
  - feature:aws s3 ls: Add --human-readable and --summarize options
    (issue 1103)
  - bugfix:aws kinesis put-records: Fix issue with base64 encoding for
    blob types (botocore issue 413)
  + From 1.7.3
  - feature:aws emr: Add support for security groups.
  - feature:aws cognitio-identity: Enhance authentication flow by beingi
    able to save associations of IAM roles with identity pools.
  + From 1.7.2
  - feature:aws autoscaling: Add ClassicLink support.
  - bugfix:aws s3: Fix issue where mtime was set before file was finished
    downloading. (issue 1102)
* Sun Jan 18 2015 rschweikert@suse.com
- Update to version 1.7.1 (bnc#905354)
  + bugfix:``aws s3 cp``: Fix issue with parts of a file being
    downloaded more than once when streaming to stdout
    (`issue 1087 <https://github.com/aws/aws-cli/pull/1087>`__)
  + bugfix:``--no-sign-request``: Fix issue where requests were still trying to
    be signed even though user used the ``--no-sign-request`` flag.
    (`botocore issue 433 <https://github.com/boto/botocore/pull/433>`__)
  + bugfix:``aws cloudsearchdomain search``: Fix invalid signatures when
    using the ``aws cloudsearchdomain search`` command
    (`issue 976 <https://github.com/aws/aws-cli/issues/976>`__)
  + feature:``aws cloudhsm``: Add support for AWS CloudHSM.
  + feature:``aws ecs``: Add support for ``aws ecs``, the Amazon EC2
    Container Service (ECS)
  + feature:``aws rds``: Add Encryption at Rest and CloudHSM Support.
  + feature:``aws ec2``: Add Classic Link support
  + feature:``aws cloudsearch``: Update ``aws cloudsearch`` command
    to latest version
  + bugfix:``aws cloudfront wait``: Fix issue where wait commands did not
    stop waiting when a success state was reached.
    (`botocore issue 426 <https://github.com/boto/botocore/pull/426>`_)
  + bugfix:``aws ec2 run-instances``: Allow binary files to be passed to
    ``--user-data``
    (`botocore issue 416 <https://github.com/boto/botocore/pull/416>`_)
  + bugfix:``aws cloudsearchdomain suggest``: Add ``--suggest-query``
    option to fix the argument being shadowed by the top level
    ``--query`` option.
    (`issue 1068 <https://github.com/aws/aws-cli/pull/1068>`__)
  + bugfix:``aws emr``: Fix issue with endpoints for ``eu-central-1`` and
    ``cn-north-1``
    (`botocore issue 423 <https://github.com/boto/botocore/pull/423>`__)
  + bugfix:``aws s3``: Fix issue where empty XML nodes are now parsed
    as an empty string ``""`` instead of ``null``, which allows for
    round tripping ``aws s3 get/put-bucket-lifecycle``
    (`issue 1076 <https://github.com/aws/aws-cli/issues/1076>`__)
  + bugfix:AssumeRole: Fix issue with cache filenames when assuming a role
    on Windows
    (`issue 1063 <https://github.com/aws/aws-cli/issues/1063>`__)
  + bugfix:``aws s3 ls``: Fix issue when listing Amazon S3 objects containing
    non-ascii characters in eu-central-1
    (`issue 1046 <https://github.com/aws/aws-cli/issues/1046>`__)
  + feature:``aws storagegateway``: Update the ``aws storagegateway`` command
    to the latest version
  + feature:``aws emr``: Update the ``aws emr`` command to the latest
    version
  + bugfix:``aws emr create-cluster``: Fix script runnner jar to the current
    region location when ``--enable-debugging`` is specified in the
    ``aws emr create-cluster`` command
  + bugfix:``aws datapipeline get-pipeline-definition``: Rename operation
    parameter ``--version`` to ``--pipeline-version`` to avoid shadowing
    a built in parameter
    (`issue 1058 <https://github.com/aws/aws-cli/pull/1058>`__)
  + bugfix:pip installation: Fix issue where pip installations would cause
    an error due to the system's python configuration
    (`issue 1051 <https://github.com/aws/aws-cli/issues/1051>`__)
  + feature:``aws elastictranscoder``: Update the ``aws elastictranscoder``
    command to the latest version
  + bugfix:Non-ascii chars: Fix issue where escape sequences were being printed
    instead of the non-ascii chars
    (`issue 1048 <https://github.com/aws/aws-cli/issues/1048>`__)
  + bugfix:``aws iam create-virtual-mfa-device``:  Fix issue with ``--outfile``
    not supporting relative paths
    (`issue 1002 <https://github.com/aws/aws-cli/pull/1002>`__)
  + feature:``aws sqs``: Add support for Amazon Simple Queue Service purge queue
    which allows users to delete the messages in their queue.
  + feature:``aws opsworks``: Add AWS OpsWorks support for registering and
    assigning existing Amazon EC2 instances and on-premises servers.
  + feature:``aws opsworks register``: Registers an EC2 instance or machine with
    AWS OpsWorks. Registering a machine using this command will install the
    AWS OpsWorks agent on the target machine and register it with an existing
    OpsWorks stack.
  + bugfix:``aws s3``: Fix issue with expired signatures when retrying
    failed requests
    (`botocore issue 399 <https://github.com/boto/botocore/pull/399>`__)
  + bugfix:``aws cloudformation get-template``: Fix error message when
    template does not exist
    (`issue 1044 <https://github.com/aws/aws-cli/issues/1044>`__)
  + feature:``aws kinesis put-records``: Add support for PutRecord operation. It
    writes multiple data records from a producer into an Amazon Kinesis
    stream in a single call
  + feature:``aws iam get-account-authorization-details``: Add support for
    GetAccountAuthorizationDetails operation. It retrieves information about
    all IAM users, groups, and roles in your account, including their
    relationships to one another and their attached policies.
  + feature:``aws route53 update-hosted-zone-comment``: Add support for updating
    the comment of a hosted zone.
  + bugfix:Timestamp Arguments: Fix issue where certain timestamps were not
    being accepted as valid input
    (`botocore issue 389 <https://github.com/boto/botocore/pull/389>`__)
  + bugfix:``aws s3``: Skip files whose names cannot be properly decoded
    (`issue 1038 <https://github.com/aws/aws-cli/pull/1038>`__)
  + bugfix:``aws kinesis put-record``: Fix issue where ``--data`` argument
    was not being base64 encoded
    (`issue 1033 <https://github.com/aws/aws-cli/issues/1033>`__)
  + bugfix:``aws cloudwatch put-metric-data``: Fix issue where the
    values for ``--statistic-values`` were not being parsed properly
    (`issue 1036 <https://github.com/aws/aws-cli/issues/1036>`__)
  + feature:``aws datapipeline``: Add support for using AWS Data Pipeline
    templates to create pipelines and bind values to parameters in the pipeline
  + feature:``aws elastictranscoder``: Add support for encryption of files in
    Amazon S3
  + bugfix:``aws s3``: Fix issue where requests were not being
    resigned correctly when using Signature Version 4
    (`botocore issue 388 <https://github.com/boto/botocore/pull/388>`__)
  + bugfix:``aws s3``: Fix issue where KMS encrypted objects could not be
    downloaded
    (`issue 1026 <https://github.com/aws/aws-cli/pull/1026>`__)
  + bugfix:``aws s3``: Fix issue where datetime's were not being
    parsed properly when a profile was specified
    (`issue 1020 <https://github.com/aws/aws-cli/issues/1020>`__)
  + bugfix:Assume Role Credential Provider: Fix issue with parsing
    expiry time from assume role credential provider
    (`botocore issue 387 <https://github.com/boto/botocore/pull/387>`__)
  + feature:``aws redshift``: Add support for integration with KMS
  + bugfix:``aws cloudtrail create-subscription``: Set a bucket config
    location constraint on buckets created outside of us-east-1.
    (`issue 1013 <https://github.com/aws/aws-cli/pull/1013>`__)
  + bugfix:``aws deploy push``: Fix s3 multipart uploads
  + bugfix:``aws s3 ls``: Fix return codes for non existing objects
    (`issue 1008 <https://github.com/aws/aws-cli/pull/1008>`__)
  + bugfix:Retrying Signed Requests: Fix issue where requests using
    Signature Version 4 signed with temporary credentials were not
    being retried properly, resulting in auth errors
    (`botocore issue 379 <https://github.com/boto/botocore/pull/379>`__)
  + bugfix:``aws s3api get-bucket-location``: Fix issue where getting the
    bucket location for a bucket in eu-central-1 required specifying
    ``--region eu-central-1``
    (`botocore issue 380 <https://github.com/boto/botocore/pull/380>`__)
  + bugfix:Timestamp Input: Fix regression where timestamps without any timezone
    information were not being handled properly
    (`issue 982 <https://github.com/aws/aws-cli/issues/982>`__)
  + bugfix:Signature Version 4: You can enable Signature Version 4 for Amazon S3
    commands by running ``aws configure set default.s3.signature_version s3v4``
    (`issue 1006 <https://github.com/aws/aws-cli/issues/1006>`__,
    `botocore issue 382 <https://github.com/boto/botocore/pull/382>`__)
  + bugfix:``aws emr``: Fix issue where ``--ssh``, ``--get``, ``--put``
    would not work when the cluster was in a waiting state
    (`issue 1007 <https://github.com/aws/aws-cli/issues/1007>`__)
  + feature:Binary File Input: Add support for reading file contents as binary
    by prepending the filename with ``fileb://``
    (`issue 1010 <https://github.com/aws/aws-cli/pull/1010>`__)
  + bugfix:Streaming Output File: Fix issue when streaming a response to a file
    and an error response is returned
    (`issue 1012 <https://github.com/aws/aws-cli/pull/1012>`__)
  + bugfix:Binary Output: Fix regression where binary output was no longer
    being base64 encoded
    (`issue 1001 <https://github.com/aws/aws-cli/pull/1001>`__,
    `issue 970 <https://github.com/aws/aws-cli/pull/970>`__)
  + feature:``aws lambda``: Add support for Amazon Lambda
  + feature:``aws s3``: Add support for S3 notifications
  + bugfix:``aws configservice get-status``: Fix connecting to endpoint without
    using ssl.
    (`issue 998 <https://github.com/aws/aws-cli/pull/998>`__)
  + bugfix:``aws deploy push``: Fix some python compatibility issues
    (`issue 1000 <https://github.com/aws/aws-cli/pull/1000>`__)
  + feature:``aws deploy``: Adds support for AWS CodeDeploy
  + feature:``aws configservice``: Adds support for AWS Config
  + feature:``aws kms``: Adds support AWS Key Management Service
  + feature:``aws s3api``: Adds support for S3 server-side encryption using
    KMS
  + feature:``aws ec2``: Adds support for EBS encryption using KMS
  + feature:``aws cloudtrail``: Adds support for CloudWatch Logs delivery
  + feature:``aws cloudformation``: Adds support for template summary.
  + feature:AssumeRole Credential Provider: Add support for assuming a role
    by configuring a ``role_arn`` and a ``source_profile`` in the AWS
    config file
    (`issue 991 <https://github.com/aws/aws-cli/pull/991>`__,
    `issue 990 <https://github.com/aws/aws-cli/pull/990>`__)
  + feature:Waiters: Add a ``wait`` subcommand that allows for a command
    to block until an AWS resource reaches a given state
    (`issue 992 <https://github.com/aws/aws-cli/pull/992>`__,
    `issue 985 <https://github.com/aws/aws-cli/pull/985>`__)
  + bugfix:``aws s3``: Fix issue where request was not properly signed
    on retried requests for ``aws s3``
    (`issue 986 <https://github.com/aws/aws-cli/issues/986>`__,
    `botocore issue 375 <https://github.com/boto/botocore/pull/375>`__)
  + bugfix:``aws s3``: Fix issue where ``--exclude`` and ``--include`` were
    not being properly applied when a s3 prefix was provided.
    (`issue 993 <https://github.com/aws/aws-cli/pull/993>`__)
  + feature:``aws cloudfront``: Adds support for wildcard cookie names and
    options caching.
  + feature:``aws route53``: Add further support for private dns and sigv4.
  + feature:``aws cognito-sync``: Add support for push sync.
  + bugfix:Pagination: Only display ``--page-size`` when an operation can be
    paginated
    (`issue 956 <https://github.com/aws/aws-cli/pull/956>`__)
  + feature:``--generate-cli-skeleton``: Generates a JSON skeleton to fill out
    and be used as input to ``--cli-input-json``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``--cli-input-json``: Runs an operation using a global JSON file
    that supplies all of the operation's arguments. This JSON file can
    be generated by ``--generate-cli-skeleton``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``aws s3/s3api``: Show hint about using the correct region when
    the corresponding error occurs
    (`issue 968 <https://github.com/aws/aws-cli/pull/968>`__)
* Thu Oct 23 2014 rschweikert@suse.com
- Update to version 1.5.3  (bnc#902598)
  + feature:aws ec2 describe-volumes: Add support for optional pagination.
  + feature:aws route53domains: Add support for auto-renew domains.
  + feature:aws cognito-identity: Add for Open-ID Connect.
  + feature:aws sts: Add support for Open-ID Connect
  + feature:aws iam: Add support for Open-ID Connect
  + bugfix:aws s3 sync: Fix issue when uploading with
  - -exact-timestamps (issue 964)
  + bugfix:Retry: Fix issue where certain error codes were not being
    retried (botocore issue 361)
  + bugfix:aws emr ssh: Fix issue when using waiter interface to wait on
    the cluster state (issue 954)
  + feature:aws cloudsearch: Add support for advance Japanese language
    processing.
  + feature:aws rds: Add support for gp2 which provides faster access than
    disk-based storage.
  + bugfix:aws s3 mv: Delete multi-part objects when transferring objects
    across regions using --source-region (issue 938)
  + bugfix:aws emr ssh: Fix issue with waiter configuration not being
    found (issue 937)
  + feature:aws dynamodb: Update aws dynamodb command to support storing
    and retrieving documents with full support for document models. New
    data types are fully compatible with the JSON standard and allow you
    to nest document elements within one another.
  + bugfix:aws configure: Fix bug where aws configure was not properly
    writing out to the shared credentials file
  + bugfix:S3 Response Parsing: Fix regression for parsing S3 responses
    containing a status code of 200 with an error response body (botocore
    issue 342)
  + bugfix:Shorthand Error Message: Ensure the error message for shorthand
    parsing always contains the CLI argument name (issue 935)
  + bugfix:Response Parsing: Fix response parsing so that leading and
    trailing spaces are preserved
  + feature:Shared Credentials File: The aws configure and aws configure set
    command now write out all credential variables to the shared
    credentials file ~/.aws/credentials (issue 847)
  + bugfix:aws s3: Write warnings and errors to standard error as opposed to
    standard output. (issue 919)
  + feature:aws s3: Add --only-show-errors option that displays errors and
    warnings but suppresses all other output.
  + feature:aws s3 cp: Added ability to upload local file streams from
    standard input to s3 and download s3 objects as local file streams to
    standard output. (issue 903)
  + feature:aws emr create-cluster: Add support for --emrfs.
  + feature:aws iam: Update aws iam command to latest version.
  + feature:aws cognito-sync: Update aws cognito-sync command to latest
    version.
  + feature:aws opsworks: Update aws opsworks command to latest version.
  + feature:aws elasticbeanstalk: Add support for bundling logs.
  + feature:aws kinesis: Add suport for tagging.
  + feature:Page Size: Add a --page-size option, that controls page size
    when perfoming an operation that uses pagination. (issue 889)
  + bugfix:aws s3: Added support for ignoring and warning about files that
    do not exist, user does not have read permissions, or are special
    files (i.e. sockets, FIFOs, character special devices, and block
    special devices) (issue 881)
  + feature:Parameter Shorthand: Added support for structure(list-scalar,
    scalar) parameter shorthand. (issue 882)
  + bugfix:aws s3: Fix bug when unknown options were passed to aws s3
    commands (issue 886)
  + bugfix:Endpoint URL: Provide a better error message when an invalid
  - -endpoint-url is provided (issue 899)
  + bugfix:aws s3: Fix issue when keys do not get properly url decoded when
    syncing from a bucket that requires pagination to a bucket that
    requires less pagination (issue 909)
  + feature:aws cloudsearchdomain: Added sigv4 support.
  + bugfix:Credentials: Raise an error if an incomplete profile is found
    (issue 690)
  + feature:Signing Requests: Add a --no-sign-request option that, when
    specified, will not sign any requests.
  + bugfix:aws s3: Added -source-region argument to allow transfer between
    non DNS compatible buckets that were located in different regions.
    (issue 872)
  + feature:aws elb: Add support for AWS Elastic Load Balancing tagging
  + feature: aws emr: Move emr out of preview mode.
  + bugfix: aws s3api: Fix serialization of several s3 api commands.
    (issue botocore 193)
  + bugfix: aws s3 sync: Fix issue for unnecessarily resyncing files on
    windows machines. (issue 843)
  + bugfix: aws s3 sync: Fix issue where keys were being decoded twice when
    syncing between buckets. (issue 862)
  + bugfix:aws ec2 describe-network-interface-attribute: Fix issue where
    the model for the aws ec2 describe-network-interface-attribute was
    incorrect (issue 558)
  + bugfix:aws s3: Add option to not follow symlinks via
  - -[no]-follow-symlinks. Note that the default behavior of following
    symlinks is left unchanged. (issue 854, issue 453, issue 781)
  + bugfix:aws route53 change-tags-for-resource: Fix serialization issue
    for aws route53 change-tags-for-resource (botocore issue 328)
  + bugfix:aws ec2 describe-network-interface-attribute: Update parameters
    to add the --attribute argument (botocore issue 327)
  + feature:aws autoscaling: Update command to the latest version
  + feature:aws elasticache: Update command to the latest version
  + feature:aws route53: Update command to the latest version
  + feature:aws route53domains: Add support for Amazon Route53 Domains
  + feature:aws elasticloadbalancing: Update to the latest service model.
  + bugfix:aws swf poll-for-decision-task: Fix issue where the default
    paginated response is missing output response keys (issue botocore 324)
  + bugfix:Connections: Fix issue where connections were hanging when
    network issues occurred issue botocore 325)
  + bugfix:aws s3/s3api: Fix issue where Deprecations were being written
    to stderr in Python 3.4.1 issue botocore 319)
  + feature:aws support: Update aws support command to the latest version
  + feature:aws iam: Update aws iam command to the latest version
  + feature:aws emr: Add --hive-site option to aws emr create-cluster and
    aws emr install-application commands
  + feature:aws s3 sync: Add an --exact-timestamps option to the aws s3
    sync command (issue 824)
  + bugfix:aws ec2 copy-snapshot: Fix bug when spaces in the description
    caused the copy request to fail (issue botocore 321)
  + feature:aws cwlogs: Add support for Amazon CloudWatch Logs
  + feature:aws cognito-sync: Add support for Amazon Cognito Service
  + feature:aws cognito-identity: Add support for Amazon Cognito Identity
    Service
  + feature:aws route53: Update aws route53 command to the latest version
  + feature:aws ec2: Update aws ec2 command to the latest version
  + bugfix:aws s3/s3api: Fix issue where --endpoint-url wasn't being used
    for aws s3/s3api commands (issue 549)
  + bugfix:aws s3 mv: Fix bug where using the aws s3 mv command to move a
    large file onto itself results in the file being deleted (issue 831)
  + bugfix:aws s3: Fix issue where parts in a multipart upload are stil being
    uploaded when a part has failed (issue 834)
  + bugfix:Windows: Fix issue where python.exe is on a path that contains
    spaces (issue 825)
  + feature:aws opsworks: Update the aws opsworks command to the latest version
  + bugfix:Shorthand JSON: Fix bug where shorthand lists with a single
    item (e.g. --arg Param=[item]) were not parsed correctly. (issue 830)
  + bugfix:Text output: Fix bug when rendering only scalars that are
    numbers in text output (issue 829)
  + bugfix:aws cloudsearchdomain: Fix bug where --endpoint-url is required
    even for help subcommands (issue 828)
  + feature:aws cloudsearchdomain: Add support for the Amazon CloudSearch
    Domain command.
  + feature:aws cloudfront: Update the Amazon CloudFront command to the
    latest version
  + feature:aws ses: Add support for delivery notifications
  + bugfix:Region Config: Fix issue for cn-north-1 region (issue botocore 314)
  + bugfix:Amazon EC2 Credential File: Fix regression for parsing EC2
    credential file (issue botocore 315)
  + bugfix:Signature Version 2: Fix timestamp format when calculating
    signature version 2 signatures (issue botocore 308)
  + feature:aws configure: Add support for setting nested attributes
    (issue 817)
  + bugfix:aws s3: Fix issue when uploading large files to newly created
    buckets in a non-standard region (issue 634)
  + feature:aws dynamodb: Add support for a local region for dynamodb
    (aws dynamodb --region local ...) (issue 608)
  + feature:aws elasticbeanstalk: Update aws elasticbeanstalk model to the
    latest version
  + feature:Documentation Examples: Add more documentatoin examples for
    many AWS CLI commands
  + feature:aws emr: Update model to the latest version
  + feature:aws elastictranscoder: Update model to the latest version
  + feature:aws s3api: Add support for server-side encryption with a
    customer-supplied encryption key.
  + feature:aws sns: Support for message attributes.
  + feature:aws redshift: Support for renaming clusters.
  + bugfix:aws s3: Fix bug related to retrying requests when 500 status
    codes are received (issue botocore 302)
  + bugfix:aws s3: Fix when when using S3 in the cn-north-1 region
    (issue botocore 301)
  + bugfix:aws kinesis: Fix pagination bug when using the get-records
    operation (issue botocore 304)
  + bugfix:Python 3.4.1: Add support for python 3.4.1 (issue 800)
  + feature:aws emr: Update preview commands for Amazon Elastic MapReduce
  + bugfix:aws s3: Add filename to error message when we're unable to stat
    local filename (issue 795)
  + bugfix:aws s3api get-bucket-policy: Fix response parsing for the aws
    s3api get-bucket-policy command (issue 678)
  + bugfix:Shared Credentials: Fix bug when specifying profiles that don't
    exist in the CLI config file (issue botocore 294)
  + bugfix:aws s3: Handle Amazon S3 error responses that have a 200 OK
    status code (issue botocore 298)
  + feature:aws sts: Update the aws sts command to the latest version
  + feature:aws cloudsearch: Update the aws cloudsearch command to the
    latest version
  + feature:Shorthand: Add support for surrounding list parameters with []
    chars in shorthand syntax (issue 788)
  + feature:Shared credential file: Add support for the ~/.aws/credentials file
  + feature:aws ec2: Add support for Amazon EBS encryption
  + bugfix:aws s3: Fix issue when --delete and --exclude filters are used
    together (issue 778)
  + feature:aws route53: Update aws route53 to the latest model
  + bugfix:aws emr: Fix issue with aws emr retry logic not being applied
    correctly (botocore issue 285)
  + feature:aws cloudtrail: Add support for eu-west-1, ap-southeast-2
  + bugfix:aws ec2: Fix issue when specifying user data from a file
    containing non-ascii characters (issue 765)
  + bugfix:aws cloudtrail: Fix a bug with python3 when creating a
    subscription (issue 773)
  + bugfix:Shorthand: Fix issue where certain shorthand parameters were
    not parsing to the correct types (issue 776)
  + bugfix:aws cloudformation: Fix issue with parameter casing for the
    NotificationARNs parameter (botocore issue 283)
  + feature:aws cloudformation: Add support for updated API
  + feature:aws sqs: Add support for message attributes
  + bugfix:aws s3api: Fix issue when setting metadata on an S3 object
    (issue 356)
  + feature:aws autoscaling: Add support for launching Dedicated Instances
    in Amazon Virtual Private Cloud
  + feature:aws elasticache: Add support to backup and restore for Redis
    clusters
  + feature:aws dynamodb: Update aws dynamodb command to the latest API
  + bugfix:Output Format: Fix issue with encoding errors when using text
    and table output and redirecting to a pipe or file (issue 742)
  + bugfix:aws s3: Fix issue with sync re-uploading certain files (issue 749)
  + bugfix:Text Output: Fix issue with inconsistent text output based on
    order (issue 751)
  + bugfix:aws datapipeline: Fix issue for aggregating keys into a list
    when calling aws datapipeline get-pipeline-definition (issue 750)
  + bugfix:aws s3: Fix issue when running out of disk space during aws s3
    transfers (issue 739)
  + feature:aws s3 sync: Add --size-only param to the aws s3 sync command
    (issue 472, issue 719)
  + bugfix:aws cloudtrail: Fix issue when using create-subscription
    command (issue botocore 268)
  + feature:aws cloudsearch: Amazon CloudSearch has moved out of preview
    (issue 730)
  + bugfix:aws s3 website: Fix issue where --error-document was being
    ignored in certain cases (issue 714)
  + feature:aws opsworks: Update aws opsworks model to the latest version
  + bugfix:Pagination: Fix issue with --max-items with aws route53, aws iam,
    and aws ses (issue 729)
  + bugfix:aws s3: Fix issue with fips-us-gov-west-1 endpoint (issue
    botocore 265)
  + bugfix:Table Output: Fix issue when displaying unicode characters in
    table output (issue 721)
  + bugfix:aws s3: Fix regression when syncing files with whitespace
    (issue 706, issue 718)
  + bugfix:aws ec2: Fix issue with EC2 model resulting in responses not
    being parsed.
  + feature:aws ec2: Add support for Amazon VPC peering
  + feature:aws redshift: Add support for the latest Amazon Redshift API
  + feature:aws cloudsearch: Add support for the latest Amazon CloudSearch API
  + bugfix:aws cloudformation: Documentation updates
  + bugfix:Argument Parsing: Fix issue when list arguments were not being
    decoded to unicode properly (issue 711)
  + bugfix:Output: Fix issue when invalid output type was provided in a
    config file or environment variable (issue 600)
  + bugfix:aws datapipeline: Fix issue when serializing pipeline definitions
    containing list elements (issue 705)
  + bugfix:aws s3: Fix issue when recursively removing keys containing
    control characters (issue 675)
  + bugfix:aws s3: Honor --no-verify-ssl in high level aws s3 commands
    (issue 696)
  + bugfix:Parameters: Fix issue parsing with CLI parameters of type long
    (issue 693)
  + bugfix:Pagination: Fix issue where --max-items in pagination was always
    assumed to be an integer (issue 689)
  + feature:aws elb: Add support for AccessLog
  + bugfix:Bundled Installer: Allow creation of bundled installer with pip
    1.5 (issue 691)
  + bugfix:aws s3: Fix issue when copying objects using aws s3 cp with key
    names containing + characters (issue #614)
  + bugfix:ec2 create-snapshot: Remove Tags key from output response
    (issue 247)
  + bugfix:aws s3: aws s3 commands should not be requiring regions (issue 681)
  + bugfix:CLI Arguments: Fix issue where unicode command line arguments
    were not being handled correctly (issue 679)
  + bugfix:aws s3: Fix issue where S3 downloads would hang in certain cases
    and could not be interrupted (issue 650, issue 657)
  + bugfix:aws s3: Support missing canned ACLs when using the --acl
    parameter (issue 663)
  + bugfix:aws rds describe-engine-default-parameters: Fix pagination issue
    when calling aws rds describe-engine-default-parameters (issue 607)
  + bugfix:aws cloudtrail: Merge existing SNS topic policy with the
    existing AWS CloudTrail policy instead of overwriting the default
    topic policy
  + bugfix:aws s3: Fix issue where streams were not being rewound when
    encountering 307 redirects with multipart uploads (issue 544)
  + bugfix:aws elb: Fix issue with documentation errors in aws elb help
    (issue 622)
  + bugfix:JSON Parameters: Add a more clear error message when parsing
    invalid JSON parameters (issue 639)
  + bugfix:aws s3api: Properly handle null inputs (issue 637)
  + bugfix:Argument Parsing: Handle files containing JSON with leading
    and trailing spaces (issue 640)
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #315990)
* Wed Feb 26 2014 rschweikert@suse.com
- update to version 1.2.13
  + feature:aws route53: Update aws route53 command to support string-match
    health checks and the UPSERT action for the aws route53
    change-resource-record-sets command
  + bugfix:Command Completion: Don't show tracebacks on SIGINT (issue 628)
  + bugfix:Docs: Don't duplicate enum values in reference docs (issue 632)
  + bugfix:aws s3: Don't require s3:// prefix (issue 626)
  + feature:aws configure: Add support for configure get and configure set
    command which allow you to set and get configuration values from the AWS
    config file (`issue 602 <https://github.com/aws/aws-cli/issues/602`__)
  + bugfix:aws s3: Fix issue with Amazon S3 downloads on certain OSes
    (`issue 619 <https://github.com/aws/aws-cli/issues/619`__)
  + Add support for the --recursive option in the aws s3 ls command
    (issue 465 <https://github.com/aws/aws-cli/issues/465)
  + Add support for the AWS_CA_BUNDLE environment variable so that users
    can specify an alternate path to a cert bundle (issue 586)
  + Add metadata_service_timeout and metadata_service_num_attempts config
    parameters to control behavior when retrieving credentials using an
    IAM role (issue 597)
  + Retry intermittent aws s3 download failures including socket timeouts
    and content length mismatches (issue 594)
  + Fix response parsing of aws s3api get-bucket-location (issue 345)
  + Fix response parsing of the aws elastictranscoder command (issue 207)
  + Update aws elasticache command to not require certain parameters
* Sat Jan 18 2014 rschweikert@suse.com
- Initial build
